@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: horde/help.php,v 2.41.2.3 2002/01/02 17:05:06 jan Exp $
+ * $Horde: horde/help.php,v 2.41.2.7 2002/05/03 02:31:05 chuck Exp $
  *
  * Copyright 1999-2002 Jon Parise <jon@horde.org>
  *
@@ -13,26 +13,21 @@ require_once HORDE_BASE . '/lib/base.php';
 require_once HORDE_BASE . '/lib/Help.php';
 
 $title = _("Help");
+$js_onLoad = null;
 $show = strtolower(Horde::getFormData('show', 'index'));
 $module = strtolower(basename(Horde::getFormData('module', 'horde')));
 $topic = Horde::getFormData('topic');
 
-if (Auth::getAuth()) {
-    $registry->pushApp($module);
-    Lang::setLang($prefs->getValue('language'));
-}
-
-$help_dir = ($module == 'horde') ? './locale/' : "./$module/locale/";
-$help_file = $help_dir . "$language/help.xml";
+$help_file = $registry->getParam('fileroot', $module) . "/locale/$language/help.xml";
 
 if ($show == 'index') {
-    include $registry->getTemplatePath('horde') . '/help/index.inc';
+    include HORDE_TEMPLATES . '/help/index.inc';
 } else {
-    include $registry->getTemplatePath('horde') . '/common-header.inc';
+    include HORDE_TEMPLATES . '/common-header.inc';
     if ($show == 'menu') {
-        include $registry->getTemplatePath('horde') . '/help/menu.inc';
+        include HORDE_TEMPLATES . '/help/menu.inc';
     } else {
-        include $registry->getTemplatePath('horde') . '/help/header.inc';
+        include HORDE_TEMPLATES . '/help/header.inc';
 
         $help = new Help(HELP_SOURCE_FILE, $help_file);
         if (($show == 'entry') && !empty($topic)) {
@@ -41,16 +36,16 @@ if ($show == 'index') {
         } else {
             $topics = $help->topics();
             foreach ($topics as $id => $title) {
-                Horde::plink($registry->getWebRoot('horde') . "/help.php?show=entry&amp;module=$module&amp;topic=$id", '', 'helpitem');
+                Horde::plink($registry->getParam('webroot', 'horde') . "/help.php?show=entry&amp;module=$module&amp;topic=$id", '', 'helpitem');
                 echo $title . "</a><br />\n";
             }
         }
         $help->cleanup();
 
-        include $registry->getTemplatePath('horde') . '/help/footer.inc';
+        include HORDE_TEMPLATES . '/help/footer.inc';
     }
 }
 
-require $registry->getTemplatePath('horde') . '/common-footer.inc';
+require HORDE_TEMPLATES . '/common-footer.inc';
 
 ?>
