@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: horde/index.php,v 2.43.2.3 2002/01/02 17:05:07 jan Exp $
+ * $Horde: horde/index.php,v 2.43.2.6 2002/03/10 00:39:39 chuck Exp $
  *
  * Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2002 Jon Parise <jon@horde.org>
@@ -10,7 +10,6 @@
  */
 
 define('HORDE_BASE', dirname(__FILE__));
-
 $horde_configured = (@file_exists('./config/horde.php') &&
                      @file_exists('./config/html.php') &&
                      @file_exists('./config/mime_drivers.php') &&
@@ -18,30 +17,28 @@ $horde_configured = (@file_exists('./config/horde.php') &&
                      @file_exists('./config/registry.php'));
 
 if ($horde_configured) {
-    require_once './lib/Registry.php';
-    $registry = &Registry::singleton();
-
-    include_once './lib/base.php';
-    include_once './lib/Secret.php';
-
-    /* Initialize the Auth credentials key. */
-    Secret::setKey('auth');
+    include_once HORDE_BASE . '/lib/base.php';
 
+    if (isset($registry->applications['horde']['initial_page'])) {
+        $main_page = Horde::applicationUrl($registry->applications['horde']['initial_page']);
+    } else {
+        $main_page = Horde::applicationUrl('login.php');
+    }
     if ($browser->hasFeature('wml')) {
-        include $registry->getTemplatePath('horde') . '/index/wap.inc';
+        include HORDE_TEMPLATES . '/index/wap.inc';
     } elseif ($conf['menu']['floating_bar'] && (!$browser->hasQuirk('avoid_popup_windows'))) {
-        $flmenu_width = count($registry->applications) * 50;
-        include $registry->getTemplatePath('horde') . '/index/floating_index.inc';
+        $flmenu_width = count($registry->applications) * 60;
+        include HORDE_TEMPLATES . '/index/floating_index.inc';
     } else {
         if ($browser->hasQuirk('scrollbar_in_way')) {
             $scrollbar = 'yes';
         } else {
             $scrollbar = 'auto';
         }
-        include $registry->getTemplatePath('horde') . '/index/frames_index.inc';
+        include HORDE_TEMPLATES . '/index/frames_index.inc';
     }
 } else {
-    include './templates/index/notconfigured.inc';
+    include HORDE_BASE . '/templates/index/notconfigured.inc';
 }
 
 ?>
