@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: horde/javascript.php,v 1.1.2.2 2002/01/02 17:05:08 jan Exp $
+ * $Horde: horde/javascript.php,v 1.1.2.3 2002/04/14 15:10:14 jan Exp $
  *
  * Copyright 2000-2002 Charles J. Hagenbuch <chuck@horde.org>
  *
@@ -21,7 +21,7 @@ $send_headers = strstr('javascript.php', $HTTP_SERVER_VARS['SCRIPT_NAME']);
 $app = Horde::getFormData('app');
 $file = basename(Horde::getFormData('file'));
 if (!empty($app) && !empty($file)) {
-    $script_file = $registry->getTemplatePath($app) . '/javascript/' . $file;
+    $script_file = $registry->getParam('templates', $app) . '/javascript/' . $file;
     if (@file_exists($script_file)) {
         if ($send_headers) {
             $mod_gmt = gmdate('D, d M Y H:i:s', filemtime($script_file)) . ' GMT';
@@ -29,7 +29,7 @@ if (!empty($app) && !empty($file)) {
             header('Cache-Control: public, max-age=86400');
             header('Content-type: text/javascript');
         }
-        
+
         $registry->pushApp($app);
         include $script_file;
     }
