@@ -1,31 +1,32 @@
 <?php
-// $Horde: horde/lib/Auth.php,v 1.22.2.2 2001/12/03 16:44:35 chuck Exp $
+// $Horde: horde/lib/Auth.php,v 1.22.2.4 2002/04/05 01:24:18 jon Exp $
 
-require_once HORDE_BASE . '/lib/Secret.php';
+require_once dirname(__FILE__) . '/Secret.php';
 
 /**
  * The Auth:: class provides a common abstracted interface into the
  * various backends for the Horde authentication system.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.22.2.2 $
+ * @version $Revision: 1.22.2.4 $
  * @since   Horde 1.3
  * @package horde.auth
  */
 class Auth {
-    
+
     /** An array of capabilities, so that the driver can report which
         operations it supports and which it doesn't.
         @var array $capabilities */
-    var $capabilities = array('add'    => false,
-                              'update' => false,
-                              'remove' => false,
-                              'list'   => false);
-     
-    
+    var $capabilities = array('add'         => false,
+                              'update'      => false,
+                              'remove'      => false,
+                              'list'        => false,
+                              'transparent' => false,
+                              'loginscreen' => false);
+
     /**
      * Attempts to return a concrete Auth instance based on $driver.
-     * 
+     *
      * @param string $driver The type of concrete Auth subclass to return.
      *                       This is based on the storage driver ($driver). The
      *                       code is dynamically included.
@@ -52,7 +53,7 @@ class Auth {
             return false;
         }
     }
-    
+
     /**
      * Attempts to return a reference to a concrete Auth instance based on
      * $driver. It will only create a new instance if no Auth instance
@@ -75,10 +76,11 @@ class Auth {
     function &singleton($driver, $params = array())
     {
         static $instances;
+        if (!isset($instances)) {
+            $instances = array();
+        }
 
-        if (!isset($instances)) $instances = array();
-
-        $signature = md5(strtolower($driver) . '][' . implode('][', $params));
+        $signature = md5(strtolower($driver) . '][' . @implode('][', $params));
         if (!isset($instances[$signature])) {
             $instances[$signature] = &Auth::factory($driver, $params);
         }
@@ -88,10 +90,10 @@ class Auth {
 
     /**
      * Find out if a set of login credentials are valid.
-     * 
+     *
      * @param string $userID       The userID to check
      * @param array  $credentials  The credentials to check
-     * 
+     *
      * @return boolean Whether or not the credentials are valid.
      */
     function authenticate($userID, $credentials)
@@ -101,7 +103,7 @@ class Auth {
 
     /**
      * Add a set of authentication credentials.
-     * 
+     *
      * @param string $userID       The userID to add.
      * @param array  $credentials  The credentials to use.
      *
@@ -109,12 +111,12 @@ class Auth {
      */
     function addUser($userID, $credentials)
     {
-        return (new PEAR_Error('unsupported'));
+        return new PEAR_Error('unsupported');
     }
 
     /**
      * Update a set of authentication credentials.
-     * 
+     *
      * @param string $oldID        The old userID.
      * @param string $newID        The new userID.
      * @param array  $credentials  The new credentials
@@ -123,84 +125,62 @@ class Auth {
      */
     function updateUser($oldID, $newID, $credentials)
     {
-        return (new PEAR_Error('unsupported'));
+        return new PEAR_Error('unsupported');
     }
 
     /**
      * Delete a set of authentication credentials.
-     * 
+     *
      * @param string $userID  The userID to delete.
      *
      * @return mixed        True on success or a PEAR_Error object on failure.
      */
     function removeUser($userID)
     {
-        return (new PEAR_Error('unsupported'));
+        return new PEAR_Error('unsupported');
     }
-    
+
     /**
      * List all users in the system.
-     * 
+     *
      * @return mixed   The array of userIDs, or a PEAR_Error object on failure.
      */
     function listUsers()
     {
-        return (new PEAR_Error('unsupported'));
+        return new PEAR_Error('unsupported');
     }
-    
+
     /**
      * Checks if there is a session with valid auth information.
      *
      * @param string $userID          The userID we are expecting in the session.
-     * @param optional string $realm  The authentication realm to check for the user.
      *
      * @return boolean                Whether or not the user is authenticated.
      */
-    function checkAuth($userID, $realm = null)
+    function checkAuth($userID)
     {
-        if (!empty($realm)) {
-            if (isset($GLOBALS['HTTP_SESSION_VARS']['__auth'][$realm])) {
-                if (!empty($GLOBALS['HTTP_SESSION_VARS']['__auth'][$realm]['authenticated']) &&
-                    !empty($GLOBALS['HTTP_SESSION_VARS']['__auth'][$realm]['userID']) &&
-                    $GLOBALS['HTTP_SESSION_VARS']['__auth'][$realm]['userID'] == $userID) {
-                    return true;
-                }
-            }
-        } else {
-            if (isset($GLOBALS['HTTP_SESSION_VARS']['__auth'])) {
-                if (!empty($GLOBALS['HTTP_SESSION_VARS']['__auth']['authenticated']) &&
-                    !empty($GLOBALS['HTTP_SESSION_VARS']['__auth']['userID']) &&
-                    $GLOBALS['HTTP_SESSION_VARS']['__auth']['userID'] == $userID) {
-                    return true;
-                }
+        if (isset($GLOBALS['HTTP_SESSION_VARS']['__auth'])) {
+            if (!empty($GLOBALS['HTTP_SESSION_VARS']['__auth']['authenticated']) &&
+                !empty($GLOBALS['HTTP_SESSION_VARS']['__auth']['userID']) &&
+                $GLOBALS['HTTP_SESSION_VARS']['__auth']['userID'] == $userID) {
+                return true;
             }
         }
         return false;
     }
-	
+
     /**
      * Return the currently logged in user, if there is one.
      *
-     * @param optional string $realm  The authentication realm to check for a user.
-     * 
      * @return mixed $userID The userID of the current user, or false
      *                       if no user is logged in.
      */
-    function getAuth($realm = null)
+    function getAuth()
     {
-        if (!empty($realm)) {
-            if (isset($GLOBALS['HTTP_SESSION_VARS']['__auth'][$realm])) {
-                if (!empty($GLOBALS['HTTP_SESSION_VARS']['__auth'][$realm]['authenticated']) &&
-                    !empty($GLOBALS['HTTP_SESSION_VARS']['__auth'][$realm]['userID'])) {
-                    return $GLOBALS['HTTP_SESSION_VARS']['__auth'][$realm]['userID'];
-                }
-            }
-        } else {
-            if (isset($GLOBALS['HTTP_SESSION_VARS']['__auth'])) {
-                if (!empty($GLOBALS['HTTP_SESSION_VARS']['__auth']['authenticated']) &&
-                    !empty($GLOBALS['HTTP_SESSION_VARS']['__auth']['userID'])) {
-                    return $GLOBALS['HTTP_SESSION_VARS']['__auth']['userID'];
-                }
+        if (isset($GLOBALS['HTTP_SESSION_VARS']['__auth'])) {
+            if (!empty($GLOBALS['HTTP_SESSION_VARS']['__auth']['authenticated']) &&
+                !empty($GLOBALS['HTTP_SESSION_VARS']['__auth']['userID'])) {
+                return $GLOBALS['HTTP_SESSION_VARS']['__auth']['userID'];
             }
         }
         return false;
@@ -210,19 +190,13 @@ class Auth {
      * Return a credential of the currently logged in user, if there is one.
      *
      * @param          string $credential  The credential to retrieve.
-     * @param optional string $realm       The authentication realm to check
-     *                                     for a user.
-     * 
+     *
      * @return mixed   The requested credential, or false
      *                 if no user is logged in.
      */
-    function getCredential($credential, $realm = null)
+    function getCredential($credential)
     {
-        if (!empty($realm) &&
-            !empty($GLOBALS['HTTP_SESSION_VARS']['__auth'][$realm]) &&
-            !empty($GLOBALS['HTTP_SESSION_VARS']['__auth'][$realm]['authenticated'])) {
-            $credentials = unserialize(Secret::read(Secret::getKey('auth'), $GLOBALS['HTTP_SESSION_VARS']['__auth'][$realm]['credentials']));
-        } else if (!empty($GLOBALS['HTTP_SESSION_VARS']['__auth']) &&
+        if (!empty($GLOBALS['HTTP_SESSION_VARS']['__auth']) &&
                    !empty($GLOBALS['HTTP_SESSION_VARS']['__auth']['authenticated'])) {
             $credentials = unserialize(Secret::read(Secret::getKey('auth'), $GLOBALS['HTTP_SESSION_VARS']['__auth']['credentials']));
         } else {
@@ -243,28 +217,23 @@ class Auth {
      *
      * @param          string $userID       The userID who has been authorized.
      * @param          array  $credentials  The credentials of the user.
-     * @param optional string $realm        The realm the user is authorized in.
      */
-    function setAuth($userID, $credentials, $realm = null)
+    function setAuth($userID, $credentials)
     {
         if (!isset($GLOBALS['HTTP_SESSION_VARS']['__auth'])) {
             session_register('__auth');
         }
         $GLOBALS['__auth'] = &$GLOBALS['HTTP_SESSION_VARS']['__auth'];
-        
+
         $credentials = Secret::write(Secret::getKey('auth'), serialize($credentials));
         $auth = array('authenticated' => true,
                       'userID' => $userID,
                       'credentials' => $credentials,
                       'timestamp' => time());
-        
-        if (!empty($realm)) {
-            $GLOBALS['__auth'][$realm] = $auth;
-        } else {
-            $GLOBALS['__auth'] = $auth;
-        }
+
+        $GLOBALS['__auth'] = $auth;
     }
-    
+
     /**
      * Clear any authentication tokens in the current session.
      */
@@ -276,7 +245,7 @@ class Auth {
             $GLOBALS['__auth']['authenticated'] = null;
         }
     }
-    
+
     /**
      * Is the current user a guest user?
      *
@@ -286,7 +255,7 @@ class Auth {
     {
         return false;
     }
-    
+
     /**
      * Query the current Auth object to find out if it supports the
      * given capability.
@@ -298,6 +267,6 @@ class Auth {
     {
         return !empty($this->capabilities[$capability]);
     }
-    
+
 }
 ?>
