@@ -1,5 +1,5 @@
 <?php
-// $Horde: horde/lib/Auth/imap.php,v 1.4.2.1 2001/12/03 15:53:53 chuck Exp $
+// $Horde: horde/lib/Auth/imap.php,v 1.4.2.3 2002/04/05 01:24:25 jon Exp $
 
 Horde::functionCheck('imap_open', true,
     'Auth_imap: Required IMAP functions were not found.');
@@ -13,10 +13,10 @@ Horde::functionCheck('imap_open', true,
  *  'protocol'      The connection protocol (e.g. 'imap', 'pop3', 'nntp').
  *  'port'          The server port to which we will connect.
  *  'folder'        The initial folder / mailbox to open.
- * 
+ *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Gaudenz Steinlin <gaudenz.steinlin@id.unibe.ch>
- * @version $Revision: 1.4.2.1 $
+ * @version $Revision: 1.4.2.3 $
  * @since   Horde 1.3
  * @package horde.auth
  */
@@ -40,7 +40,7 @@ class Auth_imap extends Auth {
 
     /**
      * Take a hash and build the connection string out of it.
-     * 
+     *
      * @param array $params   A hash specifying an IMAP mailbox.
      */
     function setParams($params)
@@ -51,19 +51,19 @@ class Auth_imap extends Auth {
             } else {
                 $params['dsn'] = '{localhost';
             }
-            
+
             if (isset($params['protocol'])) {
                 $params['dsn'] .= '/' . $params['protocol'];
             } else {
                 $params['dsn'] .= '/imap';
             }
-            
+
             if (isset($params['port'])) {
                 $params['dsn'] .= ':' . $params['port'] . '}';
             } else {
                 $params['dsn'] .= ':143}';
             }
-            
+
             if (isset($params['folder'])) {
                 $params['dsn'] .= $params['folder'];
             }
@@ -73,15 +73,14 @@ class Auth_imap extends Auth {
 
     /**
      * Find out if a set of login credentials are valid.
-     * 
+     *
      * @param string $userID       The userID to check.
      * @param array  $credentials  An array of login credentials. For IMAP,
      *                             this must contain a password entry.
-     * @param string $realm        The sub-realm to authenticate the user to.
-     * 
+     *
      * @return boolean Whether or not the credentials are valid.
      */
-    function authenticate($userID, $credentials, $realm = null)
+    function authenticate($userID, $credentials)
     {
         if (Auth::checkAuth($userID)) {
             return true;
@@ -92,7 +91,7 @@ class Auth_imap extends Auth {
 
         if ($imap) {
             @imap_close($imap);
-            Auth::setAuth($userID, $credentials, $realm);
+            Auth::setAuth($userID, $credentials);
             return true;
         }
 
