@@ -1,5 +1,5 @@
 <?php
-// $Horde: horde/lib/Auth/sql.php,v 1.21 2001/11/06 16:50:41 chuck Exp $
+// $Horde: horde/lib/Auth/sql.php,v 1.21.2.3 2002/04/05 01:24:26 jon Exp $
 
 /**
  * The Auth_sql class provides a sql implementation of the Horde
@@ -13,7 +13,7 @@
  *      'password'      The password associated with 'username'.
  *      'database'      The name of the database.
  *      'table'         The name of the auth table in 'database'.
- * 
+ *
  * Required by some database implementations:
  *      'options'       Additional options to pass to the database.
  *      'tty'           The TTY on which to connect to the database.
@@ -28,32 +28,34 @@
  *  );
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.21 $
+ * @version $Revision: 1.21.2.3 $
  * @since   Horde 1.3
  * @package horde.auth
  */
 class Auth_sql extends Auth {
-    
+
     /** An array of capabilities, so that the driver can report which
         operations it supports and which it doesn't.
         @var array $capabilities */
-    var $capabilities = array('add'    => true,
-                              'update' => true,
-                              'remove' => true,
-                              'list'   => true);
-     
+    var $capabilities = array('add'         => true,
+                              'update'      => true,
+                              'remove'      => true,
+                              'list'        => true,
+                              'transparent' => false,
+                              'loginscreen' => false);
+
     /**
      * Hash containing connection parameters.
      * @var array $params
      */
     var $params = array();
-    
+
     /**
      * Handle for the current database connection.
      * @var object DB $db
      */
     var $db;
-    
+
     /**
      * Boolean indicating whether or not we're connected to the SQL server.
      * @var boolean $connected
@@ -70,8 +72,8 @@ class Auth_sql extends Auth {
     {
         $this->params = $params;
     }
-    
-    
+
+
     /**
      * Attempts to open a persistent connection to the SQL server.
      *
@@ -109,12 +111,15 @@ class Auth_sql extends Auth {
                 Horde::fatal(new PEAR_Error(_("Unable to connect to SQL server.")), __FILE__, __LINE__);
             }
 
+            /* Enable the "portability" option. */
+            $this->db->setOption('optimize', 'portability');
+
             $this->connected = true;
         }
 
         return true;
     }
-    
+
     /**
      * Disconnect from the SQL server and clean up the connection.
      *
@@ -129,38 +134,37 @@ class Auth_sql extends Auth {
 
         return true;
     }
-    
+
     /**
      * Find out if a set of login credentials are valid.
-     * 
+     *
      * @param string $userID       The userID to check.
      * @param array  $credentials  The credentials to use.
-     * @param string $realm        The sub-realm to authenticate the user to.
-     * 
+     *
      * @return boolean Whether or not the credentials are valid.
      */
-    function authenticate($userID, $credentials, $realm = null)
+    function authenticate($userID, $credentials)
     {
         if (Auth::checkAuth($userID)) {
             return true;
         }
-        
+
         /* _connect() will die with Horde::fatal() upon failure. */
         $this->_connect();
-        
+
         /* Build the SQL query. */
         $query = 'SELECT user_uid FROM ' . $this->params['table'];
         $query .= ' WHERE user_uid = ' . $this->db->quote($userID);
         $query .= ' AND user_pass = ' . $this->db->quote(md5($credentials['password']));
-        
+
         /* Execute the query. */
         $result = $this->db->query($query);
-    
+
         if (!DB::isError($result)) {
             $row = $result->fetchRow(DB_GETMODE_ASSOC);
             if (is_array($row)) {
                 $result->free();
-                Auth::setAuth($userID, $credentials, $realm);
+                Auth::setAuth($userID, $credentials);
                 return true;
             } else {
                 $result->free();
@@ -170,37 +174,37 @@ class Auth_sql extends Auth {
             return false;
         }
     }
-    
+
     /**
      * Add a set of authentication credentials.
-     * 
+     *
      * @param string $userID       The userID to add.
      * @param array  $credentials  The credentials to add.
      *
-     * @return mixed        True on success or a PEAR_Error object on failure. 
+     * @return mixed        True on success or a PEAR_Error object on failure.
      */
     function addUser($userID, $credentials)
     {
         /* _connect() will die with Horde::fatal() upon failure. */
         $this->_connect();
-        
+
         /* Build the SQL query. */
         $query = 'INSERT INTO ' . $this->params['table'] . ' (user_uid, user_pass) ';
         $query .= 'VALUES (' . $this->db->quote($userID) . ', ' . $this->db->quote(md5($credentials['password'])) . ')';
-        
+
         /* Execute the query. */
         $result = $this->db->query($query);
-        
+
         if ($result !== DB_OK) {
             return (new PEAR_Error(_("Database query failed.")));
         }
 
         return true;
     }
-    
+
     /**
      * Update a set of authentication credentials.
-     * 
+     *
      * @param string $oldID        The old userID.
      * @param string $newID        The new userID.
      * @param array  $credentials  The new credentials
@@ -211,24 +215,24 @@ class Auth_sql extends Auth {
     {
         /* _connect() will die with Horde::fatal() upon failure. */
         $this->_connect();
-        
+
         /* Build the SQL query. */
         $query = 'UPDATE ' . $this->params['table'] . ' SET user_uid = ' . $this->db->quote($newID) . ', user_pass = ' . $this->db->quote(md5($credentials['password']));
         $query .= 'WHERE user_uid = ' . $this->db->quote($oldID);
-        
+
         /* Execute the query. */
         $result = $this->db->query($query);
-        
+
         if ($result !== DB_OK) {
             return (new PEAR_Error(_("Database query failed.")));
         }
 
         return true;
     }
-    
+
     /**
      * Delete a set of authentication credentials.
-     * 
+     *
      * @param string $userID  The userID to delete.
      * @return boolean        Success or failure.
      */
@@ -236,43 +240,43 @@ class Auth_sql extends Auth {
     {
         /* _connect() will die with Horde::fatal() upon failure. */
         $this->_connect();
-        
+
         /* Build the SQL query. */
         $query = 'DELETE FROM ' . $this->params['table'];
         $query .= ' WHERE user_uid = ' . $this->db->quote($userID);
-        
+
         /* Execute the query. */
         $result = $this->db->query($query);
-        
+
         if ($result !== DB_OK) {
             return (new PEAR_Error(_("Database query failed.")));
         }
 
         return true;
     }
-    
+
     /**
      * List all users in the system.
-     * 
+     *
      * @return mixed   The array of userIDs, or false on failure/unsupported.
      */
     function listUsers()
     {
         /* _connect() will die with Horde::fatal() upon failure. */
         $this->_connect();
-        
+
         /* Build the SQL query. */
         $query = 'SELECT user_uid from ' . $this->params['table'];
-        
+
         /* Execute the query. */
         $result = $this->db->getAll($query, null, DB_FETCHMODE_ORDERED);
-        
+
         /* Loop through and build return value. */
         $users = array();
         foreach ($result as $ar) {
             $users[] = $ar[0];
         }
-        
+
         return $users;
     }
 
