@@ -1,5 +1,5 @@
 <?php
-// $Horde: horde/lib/Browser.php,v 1.21.2.5 2001/12/15 23:02:58 chuck Exp $
+// $Horde: horde/lib/Browser.php,v 1.21.2.7 2002/05/01 17:46:06 chuck Exp $
 
 /**
  * The Browser:: class provides capability information for the current
@@ -8,28 +8,28 @@
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.21.2.5 $
+ * @version $Revision: 1.21.2.7 $
  * @since   Horde 1.3
  * @package horde
  */
 class Browser {
-    
+
     /**
      * General version numbers
      */
     var $majorVersion = 0;
     var $minorVersion = 0;
-    
+
     /**
      * Browser name
      */
     var $browser = '';
-    
+
     /**
      * Full user agent
      */
     var $agent = '';
-    
+
     /**
      * Features
      */
@@ -42,7 +42,7 @@ class Browser {
                           'java'       => true,
                           'javascript' => true,
                           'dom'        => false);
-    
+
     /**
      * Quirks
      */
@@ -52,8 +52,8 @@ class Browser {
                         'break_disposition_header' => false,
                         'empty_file_input_value'   => false,
                         'scrollbar_in_way'         => false);
-    
-    
+
+
     /**
      * Create a browser instance
      */
@@ -61,7 +61,7 @@ class Browser {
     {
         $this->match($userAgent);
     }
-    
+
     /**
      * Parses the user agent string and inititializes the object with
      * all the known features and quirks for the given browser.
@@ -77,15 +77,21 @@ class Browser {
         } else {
             $this->agent = $userAgent;
         }
-        
+
         if (!empty($this->agent)) {
             if ((preg_match('|MSIE ([0-9.]+)|', $this->agent, $version)) ||
                 (preg_match('|Internet Explorer/([0-9.]+)|', $this->agent, $version))) {
-                
+
                 $this->setBrowser('msie');
                 $this->setQuirk('cache_ssl_downloads');
-                
-                list($this->majorVersion, $this->minorVersion) = explode('.', $version[1]);
+
+                if (strstr($version[1], '.')) {
+                    list($this->majorVersion, $this->minorVersion) = explode('.', $version[1]);
+                } else {
+                    $this->majorVersion = $version[1];
+                    $this->minorVersion = 0;
+                }
+
                 switch($this->majorVersion) {
                 case 6:
                     $this->setFeature('javascript', 1.4);
@@ -107,7 +113,7 @@ class Browser {
                     $this->setQuirk('avoid_popup_windows');
                     break;
                 }
-                
+
             } elseif (preg_match('|Elaine/([0-9]+)|', $this->agent, $version) ||
                       preg_match('|Digital Paths|', $this->agent, $version)) {
                 $this->setBrowser('palm');
@@ -120,16 +126,16 @@ class Browser {
                 $this->setBrowser('fresco');
                 $this->setFeature('javascript', 1.1);
                 $this->setQuirk('avoid_popup_windows');
-                
+
             } elseif (preg_match('|Konqueror/([0-9]+)|', $this->agent, $version)) {
                 $this->setBrowser('konqueror');
                 $this->setFeature('javascript', 1.1);
                 $this->setQuirk('empty_file_input_value');
-                
+
             } elseif (preg_match('|Mozilla/([0-9.]+)|', $this->agent, $version)) {
                 $this->setBrowser('mozilla');
                 $this->setQuirk('must_cache_forms');
-                
+
                 list($this->majorVersion, $this->minorVersion) = explode('.', $version[1]);
                 switch($this->majorVersion) {
                 case 5:
@@ -144,21 +150,21 @@ class Browser {
                     $this->setFeature('javascript', 1);
                     break;
                 }
-                
+
             } elseif (preg_match('|Lynx/([0-9]+)|', $this->agent, $version)) {
                 $this->setBrowser('lynx');
                 $this->setFeature('images', false);
                 $this->setFeature('frames', false);
                 $this->setFeature('javascript', false);
                 $this->setQuirk('avoid_popup_windows');
-                
+
             } elseif (preg_match('|Links \(([0-9]+)|', $this->agent, $version)) {
                 $this->setBrowser('links');
                 $this->setFeature('images', false);
                 $this->setFeature('frames', false);
                 $this->setFeature('javascript', false);
                 $this->setQuirk('avoid_popup_windows');
-                
+
             } elseif (preg_match('|HotJava/([0-9]+)|', $this->agent, $version)) {
                 $this->setBrowser('hotjava');
                 $this->setFeature('javascript', false);
@@ -178,8 +184,8 @@ class Browser {
             }
         }
     }
-    
-    
+
+
     /**
      * Sets the current browser.
      *
@@ -189,7 +195,7 @@ class Browser {
     {
         $this->browser = $browser;
     }
-    
+
     /**
      * Determine if the given browser is the same as the current.
      *
@@ -201,7 +207,7 @@ class Browser {
     {
         return ($this->browser === $browser);
     }
-    
+
     /**
      * Retrieve the current browser.
      *
@@ -221,7 +227,7 @@ class Browser {
     {
         return $this->majorVersion;
     }
-    
+
     /**
      * Retrieve the current browser's minor version.
      *
@@ -231,7 +237,7 @@ class Browser {
     {
         return $this->minorVersion;
     }
-    
+
     /**
      * Retrieve the current browser's version.
      *
@@ -241,7 +247,7 @@ class Browser {
     {
         return $this->majorVersion . '.' . $this->minorVersion;
     }
-    
+
     /**
      * Set unique behavior for the current browser.
      *
@@ -252,7 +258,7 @@ class Browser {
     {
         $this->quirks[$quirk] = $value;
     }
-    
+
     /**
      * Check unique behavior for the current browser
      *
@@ -264,7 +270,7 @@ class Browser {
     {
         return !empty($this->quirks[$quirk]);
     }
-    
+
     /**
      * Retreive unique behavior for the current browser
      *
@@ -276,7 +282,7 @@ class Browser {
     {
         return isset($this->quirks[$quirk]) ? $this->quirks[$quirk] : null;
     }
-    
+
     /**
      * Set capabilities for the current browser.
      *
@@ -287,7 +293,7 @@ class Browser {
     {
         $this->features[$feature] = $value;
     }
-    
+
     /**
      * Check the current browser capabilities.
      *
@@ -299,7 +305,7 @@ class Browser {
     {
         return !empty($this->features[$feature]);
     }
-    
+
     /**
      * Retreive the current browser capability.
      *
@@ -311,6 +317,6 @@ class Browser {
     {
         return isset($this->features[$feature]) ? $this->features[$feature] : null;
     }
-    
+
 }
 ?>
