@@ -1,8 +1,8 @@
 <?php
-// $Horde: horde/lib/Help.php,v 1.26 2001/08/24 02:29:40 jon Exp $
+// $Horde: horde/lib/Help.php,v 1.26.2.4 2002/04/05 01:24:20 jon Exp $
 
 if (!function_exists('xml_parser_create')) {
-    die('The XML functions are not available.  Rebuild PHP with --with-xml.');
+    die('The XML functions are not available.  Rebuild PHP with --with-dom --with-xml.');
 }
 
 /* Help system constants */
@@ -19,7 +19,7 @@ define('HELP_SOURCE_DB', 2);
  * The Help:: class provides an interface to the online help subsystem.
  *
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.26 $
+ * @version $Revision: 1.26.2.4 $
  * @since   Horde 1.3
  * @package horde
  */
@@ -94,7 +94,7 @@ class Help {
 
     /**
      * Constructor
-     * 
+     *
      * @param int $source   The source of the XML help data, based on the
      *                      HELP_SOURCE_* constants.
      * @param optional string $arg  Source-dependent argument for this
@@ -324,7 +324,7 @@ class Help {
             }
         }
     }
-    
+
     /**
      * Includes the JavaScript necessary to create a new pop-up help window.
      */
@@ -332,7 +332,7 @@ class Help {
     {
         global $registry;
 
-        include_once $registry->getTemplatePath('horde') . '/javascript/open_help_win.js';
+        include_once $registry->getParam('templates', 'horde') . '/javascript/open_help_win.js';
     }
 
     /**
@@ -347,14 +347,8 @@ class Help {
     function link($module, $topic)
     {
         global $registry;
-
-        $html = '<a onmouseout="status=\'\';" onmouseover="status=\'';
-        $html .= _("Help"). '\'; return true;" ';
-        $html .= 'href="" onclick="open_help_win(\'' . $module . '\', \'';
-        $html .= $topic . '\'); return false;" tabindex="-1"><img border="0" src="';
-        $html .= $registry->getGraphicsPath("horde") . '/help.gif" width="12" ';
-        $html .= 'height="17" ';
-        $html .= ' alt="' . _("Help") . '" /></a>';
+        $html  = Horde::link('', _("Help"), '', '', "open_help_win('$module', '$topic'); return false;");
+        $html .= Horde::img('help.gif', 'alt="' . _("Help") . '" width="12" height="17"', $registry->getParam('graphics', 'horde')) . '</a>';
 
         return $html;
     }
