@@ -1,10 +1,14 @@
 <?php
-// $Horde: horde/lib/Horde.php,v 1.118.2.7 2001/12/23 15:33:48 chuck Exp $
+// $Horde: horde/lib/Horde.php,v 1.118.2.20 2002/05/22 10:08:58 jan Exp $
 
 // Horde Common Actions
+/** @constant NOOP The null action/noop. */
+define('NOOP', 0);
 /** @constant NO_ACTION The null action/noop. */
 define('NO_ACTION', 0);
 
+/** @constant HORDE_UPDATE_PREFS Update preferences. */
+define('HORDE_UPDATE_PREFS', 1);
 /** @constant UPDATE_PREFS Update preferences. */
 define('UPDATE_PREFS', 1);
 
@@ -58,14 +62,14 @@ define('HORDE_ERROR', 4);
 function _fileCleanup($filename = false, $register = true)
 {
     static $files;
-   
-    /* Initialization of variables and shutdown functions */ 
+
+    /* Initialization of variables and shutdown functions */
     if (!isset($files) || !is_array($files)) {
         $files = array();
         register_shutdown_function('_fileCleanup');
     }
-  
-    if ($register) { 
+
+    if ($register) {
         if (!$filename) {
             foreach ($files as $file => $val) {
                 if ($val && @file_exists($file)) {
@@ -86,12 +90,12 @@ function _fileCleanup($filename = false, $register = true)
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.118.2.7 $
+ * @version $Revision: 1.118.2.20 $
  * @since   Horde 1.3
  * @package horde
  */
 class Horde {
-    
+
     /**
      * Add a message to the Horde message stack.
      *
@@ -106,7 +110,7 @@ class Horde {
         global $hordeMessageStack;
         $hordeMessageStack[] = array('type' => $type, 'message' => $message);
     }
-    
+
     /**
      * Log a message to the global Horde log backend.
      *
@@ -128,18 +132,18 @@ class Horde {
     {
         static $logger;
         global $conf;
-        
+
         if (!$conf['log']['enabled']) {
             return;
         }
-        
+
         if ($priority > $conf['log']['priority']) {
             return;
         }
-        
+
         if (!isset($logger)) {
             include_once 'Log.php';
-            
+
             // Try to make sure that we can log messages somehow.
             if (!isset($conf['log']['type']) ||
                 !isset($conf['log']['name']) ||
@@ -147,7 +151,7 @@ class Horde {
                 !isset($conf['log']['params'])) {
                 Horde::fatal(new PEAR_Error('Horde is not correctly configured to log error messages. You must configure at least a text file log in horde/config/horde.php.'), __FILE__, __LINE__, false);
             }
-            
+
             $logger = Log::singleton($conf['log']['type'], $conf['log']['name'],
                                      $conf['log']['ident'], $conf['log']['params']);
 
@@ -159,20 +163,25 @@ class Horde {
                 }
             }
         }
-        
+
         if (PEAR::isError($message)) {
             $userinfo = $message->getUserInfo();
             $message = $message->getMessage();
             if (!empty($userinfo)) {
+                if (is_array($userinfo)) {
+                    $userinfo = implode(', ', $userinfo);
+                }
                 $message .= ': ' . $userinfo;
             }
         }
-        $message = '[' . $GLOBALS['registry']->getApp() . '] ' . $message . ' [on line ' . $line . ' of "' . $file . '"]';
-        
+
+        $app = isset($GLOBALS['registry']) ? $GLOBALS['registry']->getApp() : 'horde';
+        $message = '[' . $app . '] ' . $message . ' [on line ' . $line . ' of "' . $file . '"]';
+
         $logger->log($message, $priority);
         return true;
     }
-    
+
     /**
      * Abort with a fatal error, displaying debug information to the
      * user.
@@ -187,20 +196,23 @@ class Horde {
     function fatal($error, $file, $line, $log = true)
     {
         @include_once HORDE_BASE . '/lib/Text.php';
-        
-        ob_start();
-        var_dump($error);
-        $errortext = nl2br(Text::htmlspaces(ob_get_contents()));
-        ob_end_clean();
 
-        // Add the file and line if they were provided.
-        $errortext .= " [$file : $line]";
-        
+        $errortext = _("<b>A fatal error has occurred:</b>") . "<br /><br />\n";
+        if (is_object($error) && method_exists($error, 'getMessage')) {
+            $errortext .= $error->getMessage() . "<br /><br />\n";
+        }
+        $errortext .= sprintf(_("[line %s of %s]"), $line, $file);
+
+        if ($log) {
+            $errortext .= "<br /><br />\n";
+            $errortext .= _("Details have been logged for the administrator.");
+        }
+
         // Log the fatal error via Horde::logMessage() if requested.
         if ($log) {
-            Horde::logMessage($errortext, __FILE__, __LINE__, LOG_EMERG);
+            Horde::logMessage($error, $file, $line, LOG_EMERG);
         }
-        
+
         // Hardcode a small stylesheet so that this doesn't depend on
         // anything else.
         echo <<< HTML
@@ -210,22 +222,19 @@ class Horde {
 <title>Horde :: Fatal Error</title>
 <style type="text/css">
 <!--
-body { font-family: Geneva,Arial,Helvetica,sans-serif; font-size: 12px; background-color: #222244; color: black; }
-.smallheader { color: #ccccee; background-color: #444466; font-family: Geneva,Arial,Helvetica,sans-serif; font-size: 12px; }
-.light { color: white; font-family: Geneva,Arial,Helvetica,sans-serif; font-size: 12px; }
-.header { color: #ccccee; background-color: #444466; font-family: Verdana,Helvetica,sans-serif; font-weight: bold; font-size: 17px; }
+body { font-family: Geneva,Arial,Helvetica,sans-serif; font-size: 12px; background-color: #222244; color: #ffffff; }
+.header { color: #ccccee; background-color: #444466; font-family: Verdana,Helvetica,sans-serif; font-size: 12px; }
 -->
 </style>
 </head>
 <body>
-<table border="0" align="center" width="500" cellpadding="2" cellspacing="4">
-<tr><td class="header" align="center"><b>A fatal error has occurred</b></td></tr>
-<tr><td class="smallheader"><tt>$errortext</tt></td></tr>
+<table border="0" align="center" width="500" cellpadding="2" cellspacing="0">
+<tr><td class="header" align="center">$errortext</td></tr>
 </table>
 </body>
 </html>
 HTML;
-        
+
         exit;
     }
 
@@ -256,10 +265,12 @@ HTML;
             return false;
         }
     }
-    
+
     /**
      * Return a session-id-ified version of $uri.
      *
+     * @access public
+     *
      * @param string  $uri The URI to be modified.
      * @param boolean $full Generate a full (http://server/path/) URL.
      * @param boolean $always_append_session Tack on the session ID even if
@@ -285,14 +296,14 @@ HTML;
                     $protocol = 'https';
                 }
             }
-            
+
             if ($server_port != 80 && $server_port != 443) {
                 $server_name .= ':' . $server_port;
             }
 
             /* Store the webroot in a local variable. */
-            $webroot = $registry->getWebRoot();
-            
+            $webroot = $registry->getParam('webroot');
+
             $url = $protocol . '://' . $server_name;
             if (substr($uri, 0, 1) != '/') {
                 if (substr($webroot, -1) == '/') {
@@ -306,25 +317,45 @@ HTML;
         } else {
             $url = $uri;
         }
-        
+
         if ($always_append_session ||
             !isset($GLOBALS['HTTP_COOKIE_VARS'][session_name()])) {
-            $pos = strpos($url, '?');
-            $enc = urlencode(session_name()) . '=' . session_id();
-            if ($pos !== false) {
-                $url = substr_replace($url, $enc . '&', $pos + 1, 0);
-            } else {
-                $url .= '?' . $enc;
-            }
+            $url = Horde::addParameter($url, urlencode(session_name()) . '=' . session_id());
         }
-        
+
         return ($full ? $url : htmlentities($url));
     }
-    
+
+    /**
+     * Add a name=value pair to an URL, taking care of whether there
+     * are existing parameters and whether to use ? or & as the glue.
+     *
+     * @access public
+     *
+     * @param string $url       The URL to modify
+     * @param string $parameter The name=value pair to add.
+     *
+     * @return string The modified URL.
+     */
+    function addParameter($url, $parameter)
+    {
+        if (strstr($url, $parameter) === false) {
+            $pos = strpos($url, '?');
+            if ($pos !== false) {
+                $url = substr_replace($url, $parameter . '&', $pos + 1, 0);
+            } else {
+                $url .= '?' . $parameter;
+            }
+        }
+        return $url;
+    }
+
     /**
      * Return a session-id-ified version of $uri, using the current
      * application's webroot setting.
      *
+     * @access public
+     *
      * @param string  $uri The URI to be modified.
      * @param boolean $full Generate a full (http://server/path/) URL.
      * @param boolean $always_append_session Tack on the session ID even if
@@ -337,8 +368,8 @@ HTML;
         global $registry;
 
         /* Store the webroot in a local variable. */
-        $webroot = $registry->getWebRoot();
-        
+        $webroot = $registry->getParam('webroot');
+
         if ($full) {
             return Horde::url($uri, $full, $always_append_session);
         } elseif (substr($webroot, -1) == '/') {
@@ -347,27 +378,30 @@ HTML;
             return Horde::url($webroot . '/' . $uri, $full, $always_append_session);
         }
     }
-    
+
     /**
-     * Return an anchor tag with the relevant parameters 
+     * Return an anchor tag with the relevant parameters
      *
-     * @param string $url The full URL to be linked to
-     * @param string $status An optional JavaScript mouse-over string
-     * @param string $class The CSS class of the link
-     * @param string $target The window target to point this link too
+     * @access public
+     *
+     * @param string $url     The full URL to be linked to
+     * @param string $status  An optional JavaScript mouse-over string
+     * @param string $class   The CSS class of the link
+     * @param string $target  The window target to point this link too
      * @param string $onclick JavaScript action for the 'onclick' event.
+     * @param string $title   The link title (tooltip)
      *
      * @return string The full <a href> tag.
      */
-    function link($url, $status = '', $class = '', $target = '', $onclick = '')
+    function link($url, $status = '', $class = '', $target = '', $onclick = '', $title = '')
     {
         $ret = "<a href=\"$url\"";
         if (!empty($onclick)) {
             $ret .= " onclick=\"$onclick\"";
         }
         if (!empty($status)) {
-            $ret .= ' onmouseout="status=\'\';" onmouseover="status=\''.
-                htmlentities(addslashes($status)) . '\'; return true;"';
+            $ret .= ' onmouseout="window.status=\'\';" onmouseover="window.status=\'' .
+                htmlspecialchars(addslashes($status), ENT_QUOTES, Lang::getCharset()) . '\'; return true;"';
         }
         if (!empty($class)) {
             $ret .= " class=\"$class\"";
@@ -375,27 +409,35 @@ HTML;
         if (!empty($target)) {
             $ret .= " target=\"$target\"";
         }
-        
+        if (!empty($title)) {
+            $ret .= ' title="' . htmlspecialchars($title, ENT_QUOTES, Lang::getCharset()) . '"';
+        }
+
         return "$ret>";
     }
 
     /**
      * Print an anchor tag with the relevant parameters
      *
+     * @access public
+     *
      * @param string $url The full URL to be linked to
      * @param string $status An optional JavaScript mouse-over string
      * @param string $class The CSS class of the link
      * @param string $target The window target to point this link too
      * @param string $onclick JavaScript action for the 'onclick' event.
+     * @param string $title   The link title (tooltip)
      */
-    function plink($url, $status = '', $class = '', $target = '')
+    function plink($url, $status = '', $class = '', $target = '', $onclick = '', $title = '')
     {
-       echo Horde::link($url, $status, $class, $target);
+       echo Horde::link($url, $status, $class, $target, $onclick, $title);
     }
 
     /**
      * Print a session-id-ified version of the URI.
      *
+     * @access public
+     *
      * @param string  $uri the URI to be modified
      * @param boolean $full Generate a full (http://server/path/) URL.
      * @param boolean $always_append_session Tack on the session ID even if
@@ -409,24 +451,28 @@ HTML;
     /**
      * Return a session-id-ified version of $PHP_SELF.
      *
+     * @access public
+     *
      * @param string $query_string (optional) include the query string?
      */
     function selfURL($query_string = false)
     {
         global $HTTP_SERVER_VARS;
-        
+
         $url = $HTTP_SERVER_VARS['PHP_SELF'];
-        
+
         if ($query_string && !empty($HTTP_SERVER_VARS['QUERY_STRING'])) {
             $url .= '?' . $HTTP_SERVER_VARS['QUERY_STRING'];
         }
-        
+
         return Horde::url($url);
     }
 
     /**
      * Print a session-id-ified version of $PHP_SELF.
      *
+     * @access public
+     *
      * @param $query_string (optional) include the query string?
      */
     function pselfURL($query_string = false)
@@ -436,6 +482,8 @@ HTML;
 
     /**
      * Return a hidden form input containing the session name and id.
+     *
+     * @access public
      */
     function formInput()
     {
@@ -444,6 +492,8 @@ HTML;
 
     /**
      * Print a hidden form input containing the session name and id.
+     *
+     * @access public
      */
     function pformInput()
     {
@@ -453,6 +503,8 @@ HTML;
     /**
      * Construct a correctly-pathed link to an image
      *
+     * @access public
+     *
      * @param          string $src  The image file.
      * @param optional string $attr Any extra parameters for the image tag.
      * @param optional string $dir  The root graphics directory.
@@ -463,26 +515,31 @@ HTML;
     {
         if ($dir === null) {
             global $registry;
-            $dir = $registry->getGraphicsPath();
+            $dir = $registry->getParam('graphics');
         }
-        
+
         $img = '<img';
         $img .= ' src="' . (empty($dir) ? '' : $dir . '/') . $src . '"';
         $img .= ' border="0"';
         if (!empty($attr)) {
             $img .= ' ' . $attr;
+            if (preg_match('/alt=[\'"]([^\'"]*)[\'"]/i', $attr, $match)) {
+                $img .= ' title="'. $match[1] . '"';
+            }
         }
         if (empty($attr) || !strstr($attr, 'alt')) {
             $img .= ' alt=""';
         }
         $img .= ' />';
-        
+
         return $img;
     }
-    
+
     /**
      * Construct a correctly-pathed link to an image
      *
+     * @access public
+     *
      * @param string $src  The image file.
      * @param string $attr Any extra parameters for the image tag.
      * @param string $dir  The root graphics directory.
@@ -491,34 +548,40 @@ HTML;
     {
         echo Horde::img($src, $attr, $dir);
     }
-    
+
     /**
      * If magic_quotes_gpc is in use, run stripslashes() on $var.
      *
+     * @access public
+     *
      * @param  string $var The string to un-quote, if necessary.
      * @return string      $var, minus any magic quotes.
      */
-    function dispelMagicQuotes($var)
+    function dispelMagicQuotes(&$var)
     {
         static $magic_quotes;
-        
+
         if (!isset($magic_quotes)) {
             $magic_quotes = get_magic_quotes_gpc();
         }
-        
+
         if ($magic_quotes) {
             if (!is_array($var)) {
                 $var = stripslashes($var);
+            } else {
+                array_walk($var, array('Horde', 'dispelMagicQuotes'));
             }
         }
-        
+
         return $var;
     }
-    
+
     /**
      * Get a form variable from GET or POST data, stripped of magic
      * quotes if necessary.
      *
+     * @access public
+     *
      * @param string $var The name of the form variable to look for.
      * @param string $default (optional) The value to return if the
      *                                   variable is not there.
@@ -540,6 +603,8 @@ HTML;
      * Determine the location of the system temporary directory.
      * If a specific setting cannot be found, it defaults to /tmp
      *
+     * @access public
+     *
      * @return string    A directory name which can be used for temp files
      *                   or false if one could not be found
      */
@@ -551,7 +616,7 @@ HTML;
         if (!empty($GLOBALS['conf']['tmpdir'])) {
             $tmp = $GLOBALS['conf']['tmpdir'];
         }
-        
+
         /* Next, try PHP's upload_tmp_dir directive. */
         if (empty($tmp)) {
             $tmp = ini_get('upload_tmp_dir');
@@ -570,7 +635,7 @@ HTML;
             if (@is_dir($tmp_check)) {
                 $tmp = $tmp_check;
             }
-        } 
+        }
 
         /* If it is still empty, we have failed, so return false;
          * otherwise return the directory determined. */
@@ -581,6 +646,8 @@ HTML;
      * Create a temporary filename for the lifetime of the script, and
      * (optionally) register it to be deleted at request shutdown.
      *
+     * @access public
+     *
      * @param string $prefix  Prefix to make the temporary name more recognizable
      * @param optional boolean $delete Delete the file at the end of the request?
      * @param optional string $dir Directory to create the temporary file in
@@ -598,7 +665,7 @@ HTML;
         if (empty($tmp_dir)) {
             return false;
         }
-        
+
         $tmp_file = tempnam($tmp_dir, $prefix);
 
         /* If the file was created, then register it for deletion and return */
@@ -611,6 +678,6 @@ HTML;
             return $tmp_file;
         }
     }
-
 }
+
 ?>
