@@ -1,5 +1,5 @@
 <?php
-// $Horde: horde/lib/MIME.php,v 1.64 2001/08/09 13:24:17 chuck Exp $
+// $Horde: horde/lib/MIME.php,v 1.64.2.2 2002/04/06 16:19:19 jan Exp $
 
 $mime_types =
 array(
@@ -13,7 +13,7 @@ array(
       TYPEOTHER => 'unknown', 'unknown' => TYPEOTHER
       );
 
-$mime_encodings = 
+$mime_encodings =
 array(
       ENC7BIT => '7bit', '7bit' => ENC7BIT,
       ENC8BIT => '8bit', '8bit' => ENC8BIT,
@@ -28,12 +28,12 @@ array(
  * The MIME:: class provides methods for dealing with MIME standards.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.64 $
+ * @version $Revision: 1.64.2.2 $
  * @since   Horde 1.3
  * @package horde.mime
  */
 class MIME {
-    
+
     /**
      * Determine if a string contains 8-bit characters.
      * @access private
@@ -52,7 +52,7 @@ class MIME {
         }
         return false;
     }
-    
+
     /**
      * Encode a string containing non-ascii characters according to RFC 2047.
      *
@@ -71,15 +71,15 @@ class MIME {
                 $text = "=?$charset?B?" . strtr(trim(base64_encode($text)), ' ', '_') . "?=\n\t";
             }
         }
-        
+
         // if this is the final iteration, take off any trailing
         // newline/tab chars.
         if ($outer && (substr($text, -2) == "\n\t"))
             $text = substr($text, 0, -2);
-        
+
         return $text;
     }
-    
+
     /**
      * Encode a string containing email addresses according to RFC 2047.
      *
@@ -95,7 +95,7 @@ class MIME {
     function encodeAddress($text, $charset = null, $defserver = null)
     {
         include_once 'Mail/RFC822.php';
-        
+
         $addr_arr = Mail_RFC822::parseAddressList($text, $defserver, false, false);
         $text = '';
         if (is_array($addr_arr)) {
@@ -116,7 +116,7 @@ class MIME {
         }
         return $text;
     }
-    
+
     /**
      * Decode an RFC 2047-encoded string.
      *
@@ -129,37 +129,37 @@ class MIME {
         if ($pos === false) {
             return $string;
         }
-        
+
         // take out any spaces between multiple encoded words
         $string = preg_replace('|\?=\s=\?|', '?==?', $string);
-        
+
         $preceding = substr($string, 0, $pos); // save any preceding text
-        
+
         $search = substr($string, $pos + 2, 75); // the mime header spec says this is the longest a single encoded word can be
         $d1 = strpos($search, '?');
         if (!is_int($d1)) {
             return $string;
         }
-        
+
         $charset = substr($string, $pos + 2, $d1);
         $search = substr($search, $d1 + 1);
-        
+
         $d2 = strpos($search, '?');
         if (!is_int($d2)) {
             return $string;
         }
-        
+
         $encoding = substr($search, 0, $d2);
         $search = substr($search, $d2+1);
-        
+
         $end = strpos($search, '?=');
         if (!is_int($end)) {
             return $string;
         }
-        
+
         $encoded_text = substr($search, 0, $end);
         $rest = substr($string, (strlen($preceding . $charset . $encoding . $encoded_text) + 6));
-        
+
         switch ($encoding) {
         case 'Q':
         case 'q':
@@ -168,42 +168,42 @@ class MIME {
             $decoded = urldecode($encoded_text);
 
             /* Convert Cyrillic character sets. */
-            if (stristr($GLOBALS['registry']->getCharset(), 'windows-1251')) {
+            if (stristr(Lang::getCharset(), 'windows-1251')) {
                 if (stristr($charset, 'koi8-r')) {
                     $decoded = convert_cyr_string($decoded, 'k', 'w');
                 }
             }
-            if (stristr($GLOBALS['registry']->getCharset(), 'koi8-r')) {
+            if (stristr(Lang::getCharset(), 'koi8-r')) {
                 if (stristr($charset, 'windows-1251')) {
                     $decoded = convert_cyr_string($decoded, 'w', 'k');
                 }
             }
-            
+
             break;
-            
+
         case 'B':
         case 'b':
             $decoded = urldecode(base64_decode($encoded_text));
-            if (stristr($GLOBALS['registry']->getCharset(), 'windows-1251')) {
+            if (stristr(Lang::getCharset(), 'windows-1251')) {
                 if (stristr($charset, 'koi8-r')) {
                     $decoded = convert_cyr_string($decoded, 'k', 'w');
                 }
             }
-            if (stristr($GLOBALS['registry']->getCharset(), 'koi8-r')) {
+            if (stristr(Lang::getCharset(), 'koi8-r')) {
                 if (stristr($charset, 'windows-1251')) {
                     $decoded = convert_cyr_string($decoded, 'w', 'k');
                 }
             }
             break;
-            
+
         default:
             $decoded = '=?' . $charset . '?' . $encoding . '?' . $encoded_text . '?=';
             break;
         }
-        
+
         return $preceding . $decoded . MIME::decode($rest);
     }
-    
+
     /**
      * If an email address has no personal information, get rid of any
      * angle brackets (<>) around it.
@@ -219,6 +219,6 @@ class MIME {
         }
         return $address;
     }
-    
+
 }
 ?>
