@@ -1,5 +1,5 @@
 <?php
-// $Horde: horde/lib/MIME/Message.php,v 1.9.2.2 2001/12/03 16:57:05 chuck Exp $
+// $Horde: horde/lib/MIME/Message.php,v 1.9.2.4 2002/04/06 16:19:20 jan Exp $
 
 require_once dirname(__FILE__) . '/Part.php';
 
@@ -8,25 +8,25 @@ require_once dirname(__FILE__) . '/Part.php';
  * messages.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.9.2.2 $
+ * @version $Revision: 1.9.2.4 $
  * @since   Horde 1.3
  * @package horde.mime
  */
 class MIME_Message {
-    
+
     /** The string that separates MIME parts from each other inside the message.
         @var string $separator */
     var $separator;
-    
+
     /** The array of MIME parts in the message.
         @var array $parts */
     var $parts;
-    
+
     /** The server to default unqualified addresses to.
         @var string $defaultServer */
     var $defaultServer;
-    
-    
+
+
     /**
      * Create a new MIME email message.
      *
@@ -43,8 +43,8 @@ class MIME_Message {
             $this->defaultServer = $defaultServer;
         }
     }
-    
-    
+
+
     /**
      * Add a MIME_Part object to this message.
      *
@@ -54,7 +54,7 @@ class MIME_Message {
     {
         $this->parts[] = $part;
     }
-    
+
     /**
      * Take a set of headers and make sure they are encoded properly.
      *
@@ -64,7 +64,7 @@ class MIME_Message {
     function encode($headers)
     {
         global $HTTP_SERVER_VARS;
-        
+
         if (!empty($HTTP_SERVER_VARS['HTTP_ACCEPT_CHARSET'])) {
             $charsets = explode(',', $HTTP_SERVER_VARS['HTTP_ACCEPT_CHARSET']);
             if (!empty($charsets[0])) {
@@ -75,7 +75,7 @@ class MIME_Message {
             }
         }
         if (empty($charset)) {
-            $charset = $GLOBALS['registry']->getCharset();
+            $charset = Lang::getCharset();
         }
 
         foreach ($headers as $key => $val) {
@@ -87,7 +87,7 @@ class MIME_Message {
         }
         return $headers;
     }
-    
+
     /**
      * Add the proper set of MIME headers for this message to an array.
      *
@@ -105,7 +105,7 @@ class MIME_Message {
         }
         return $headers;
     }
-    
+
     /**
      * Return the entire message contents, including headers, as a string.
      *
@@ -127,9 +127,9 @@ class MIME_Message {
             }
             $message .= "\n--$this->separator--\n";
         }
-        
+
         return $message;
     }
-    
+
 }
 ?>
