@@ -1,5 +1,5 @@
 <?php
-// $Horde: horde/lib/Prefs.php,v 1.57.2.1 2001/12/10 19:14:39 chuck Exp $
+// $Horde: horde/lib/Prefs.php,v 1.57.2.4 2002/04/05 01:26:21 jon Exp $
 
 require_once HORDE_BASE . '/lib/Horde.php';
 
@@ -13,6 +13,9 @@ define('_PREF_SHARED', 2);
 /** @constant _PREF_DIRTY Preference value has been changed. */
 define('_PREF_DIRTY', 4);
 
+/** @constant _PREF_DEFAULT Preference value is the application default. */
+define('_PREF_DEFAULT', 8);
+
 
 /**
  * The Prefs:: class provides a common abstracted interface into the
@@ -22,12 +25,12 @@ define('_PREF_DIRTY', 4);
  * TODO: document the format of the $_prefs hash here
  *
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.57.2.1 $
+ * @version $Revision: 1.57.2.4 $
  * @since   Horde 1.3
  * @package horde.prefs
  */
 class Prefs {
-    
+
     /**
      * Hash holding all of the user's preferences. Each preference is
      * itself a hash, so this will ultimately be multi-dimensional.
@@ -36,8 +39,8 @@ class Prefs {
     var $prefs = array();
 
     /**
-     * String containing the name of this scope.  This is used to
-     * maintain the application scope between sets of preferences.  By
+     * String containing the name of this scope. This is used to
+     * maintain the application scope between sets of preferences. By
      * default, all preferences belong to the "global" (Horde) scope.
      * @var string $scope
      */
@@ -55,10 +58,17 @@ class Prefs {
      * @var boolean $caching
      */
     var $caching = false;
-    
+
+    /**
+     * Array of boolean flags indicating whether the default preferences
+     * stored in the given file have been loaded.
+     * @var boolean $defaults
+     */
+    var $defaults = array();
+
     /**
      * Attempts to return a concrete Prefs instance based on $driver.
-     * 
+     *
      * @param string $driver    The type of concrete Prefs subclass to return.
      *                          This is based on the storage driver ($driver).
      *                          The code is dynamically included.
@@ -81,14 +91,14 @@ class Prefs {
         if ($caching) {
             if (!session_is_registered('prefs_cache')) {
                 global $prefs_cache;
-                
+
                 $prefs_cache = array();
                 $prefs_cache['_filled'] = array();
-                
+
                 $GLOBALS['HTTP_SESSION_VARS']['prefs_cache'] = &$prefs_cache;
-                
+
                 /* If we fail to register the cache, continue on without it. */
-                if (!session_register('prefs_cache')) {
+                if (!@session_register('prefs_cache')) {
                     unset($prefs_cache);
                     $caching = false;
                 }
@@ -111,7 +121,7 @@ class Prefs {
         if (!empty($params['user_hook'])) {
             $user = call_user_func($params['user_hook'], $user);
         }
-        
+
         @include_once dirname(__FILE__) . '/Prefs/' . $driver . '.php';
         $class = 'Prefs_' . $driver;
         if (class_exists($class)) {
@@ -150,19 +160,19 @@ class Prefs {
                         $params = array(), $caching = true)
     {
         static $instances;
-        
+
         if (!isset($instances)) $instances = array();
-        
+
         $signature = md5(strtolower($driver) . '][' . $user . '][' .
             implode('][', $params));
         if (!isset($instances[$signature])) {
             $instances[$signature] = &Prefs::factory($driver, $scope, $user,
                 $password, $params, $caching);
         }
-        
+
         return $instances[$signature];
     }
-    
+
     /**
      * Populates the $prefs hash with new entries and externally defined
      * default values.
@@ -172,39 +182,40 @@ class Prefs {
      */
     function setDefaults($filename)
     {
-        /* Ensure that the defaults are only read once. */
-        static $completed;
-        if (!empty($completed[$filename])) {
+        /* Ensure that the defaults from this file are only read once. */
+        if (!empty($this->defaults[$filename])) {
             return;
-        } else {
-            $completed[$filename] = true;
         }
 
         if (!@is_readable($filename)) return;
-        
+
         /* Read the configuration file. The $_prefs array, which will
          * be in local scope, is assumed to hold the default
          * values. */
         include $filename;
-        
+
         foreach ($_prefs as $pref => $pvals) {
             if (isset($pvals['value']) && isset($pvals['locked']) &&
                 isset($pvals['shared']) && ($pvals['type'] != 'link') &&
                 ($pvals['type'] != 'special')) {
                 $pref = str_replace('.', '_', $pref);
-                $acl = 0;
+                $mask = 0;
                 if ($pvals['locked']) {
-                    $acl |= _PREF_LOCKED;
+                    $mask |= _PREF_LOCKED;
                 }
                 if ($pvals['shared']) {
-                    $acl |= _PREF_SHARED;
+                    $mask |= _PREF_SHARED;
                 }
-                $acl &= ~_PREF_DIRTY;
+                $mask &= ~_PREF_DIRTY;
+                $mask |= _PREF_DEFAULT;
 
-                $this->add($pref, $pvals['value'], $acl);
+                $this->add($pref, $pvals['value'], $mask);
             }
         }
 
+        /* Indicate that the defaults from this file have been loaded. */
+        $this->defaults[$filename] = true;
+
         /* If the cache is already filled, don't overwrite it with the
            defaults we've just read in. */
         if (session_is_registered('prefs_cache')) {
@@ -217,7 +228,7 @@ class Prefs {
         /* Update the preferences cache with the defaults. */
         $this->cacheUpdate();
     }
-    
+
     /**
      * Updates the session-based preferences cache (if available) with the
      * current set of preferences.
@@ -229,7 +240,7 @@ class Prefs {
 
         if (session_is_registered('prefs_cache')) {
             global $prefs_cache;
-            
+
             /* Place each preference in the cache according to itsscope. */
             foreach ($this->prefs as $name => $pref) {
                 $prefs_cache[$this->getScope($name)][$name] = $pref;
@@ -252,7 +263,7 @@ class Prefs {
 
         if (session_is_registered('prefs_cache')) {
             global $prefs_cache;
-            
+
             /* If we haven't filled the cache yet, force a retrieval. */
             if (empty($prefs_cache['_filled'][$this->scope])) {
                 $prefs_cache['_filled'][$this->scope] = true;
@@ -283,14 +294,14 @@ class Prefs {
     /**
      * Adds a new preference entry to the $prefs hash.
      *
-     * @param string  $pref      The name of the preference to add.
-     * @param string  $val       (optional) The initial value of the preference.
-     * @param integer $acl       (optional) The initial ACL of the preference.
+     * @param string  $pref    The name of the preference to add.
+     * @param string  $val     (optional) The initial value of the preference.
+     * @param integer $mask    (optional) The initial bitmask of the preference.
      */
-    function add($pref, $val = '', $acl = 0)
+    function add($pref, $val = '', $mask = 0)
     {
         if (is_array($this->prefs)) {
-            $this->prefs[$pref] = array('val' => $val, 'acl' => $acl);
+            $this->prefs[$pref] = array('val' => $val, 'mask' => $mask);
         }
     }
 
@@ -334,20 +345,22 @@ class Prefs {
         if (!isset($this->prefs[$pref]) || $this->isLocked($pref)) {
             return false;
         }
-        
+
         /*
          * If the preference's value is already equal to $val, don't bother
          * changing it.  Changing it would set the "dirty" bit, causing an
          * unnecessary update later on in the storage routine.
          */
-        if ($this->prefs[$pref]['val'] == $val) {
+        if ($this->prefs[$pref]['val'] == $val && !$this->isDefault($pref)) {
             return true;
         }
-        
-        /* Assign the new value and set the "dirty" bit. */
+
+        /* Assign the new value, unset the "default" bit, and set the
+           "dirty" bit. */
         $this->prefs[$pref]['val'] = $val;
+        $this->setDefault($pref, false);
         $this->setDirty($pref, true);
-        
+
         return true;
     }
 
@@ -362,7 +375,7 @@ class Prefs {
     {
         return (isset($this->prefs[$pref]['val'])) ? $this->prefs[$pref]['val'] : null;
     }
-    
+
     /**
      * Modifies the "locked" bit for the given preference.
      *
@@ -374,9 +387,9 @@ class Prefs {
         if (isset($this->prefs[$pref])) {
             if ($bool != $this->isLocked($pref)) {
                 if ($bool) {
-                    $this->prefs[$pref]['acl'] |= _PREF_LOCKED;
+                    $this->prefs[$pref]['mask'] |= _PREF_LOCKED;
                 } else {
-                    $this->prefs[$pref]['acl'] &= ~_PREF_LOCKED;
+                    $this->prefs[$pref]['mask'] &= ~_PREF_LOCKED;
                 }
             }
         }
@@ -391,8 +404,8 @@ class Prefs {
      */
     function isLocked($pref)
     {
-        if (isset($this->prefs[$pref]['acl'])) {
-            return ($this->prefs[$pref]['acl'] & _PREF_LOCKED);
+        if (isset($this->prefs[$pref]['mask'])) {
+            return ($this->prefs[$pref]['mask'] & _PREF_LOCKED);
         }
         return false;
     }
@@ -408,9 +421,9 @@ class Prefs {
         if (isset($this->prefs[$pref])) {
             if ($bool != $this->isShared($pref)) {
                 if ($bool) {
-                    $this->prefs[$pref]['acl'] |= _PREF_SHARED;
+                    $this->prefs[$pref]['mask'] |= _PREF_SHARED;
                 } else {
-                    $this->prefs[$pref]['acl'] &= ~_PREF_SHARED;
+                    $this->prefs[$pref]['mask'] &= ~_PREF_SHARED;
                 }
             }
         }
@@ -425,8 +438,8 @@ class Prefs {
      */
     function isShared($pref)
     {
-        if (isset($this->prefs[$pref]['acl'])) {
-            return ($this->prefs[$pref]['acl'] & _PREF_SHARED);
+        if (isset($this->prefs[$pref]['mask'])) {
+            return ($this->prefs[$pref]['mask'] & _PREF_SHARED);
         }
         return false;
     }
@@ -454,9 +467,9 @@ class Prefs {
         if (isset($this->prefs[$pref])) {
             if ($bool != $this->isDirty($pref)) {
                 if ($bool) {
-                    $this->prefs[$pref]['acl'] |=  _PREF_DIRTY;
+                    $this->prefs[$pref]['mask'] |=  _PREF_DIRTY;
                 } else {
-                    $this->prefs[$pref]['acl'] &= ~_PREF_DIRTY;
+                    $this->prefs[$pref]['mask'] &= ~_PREF_DIRTY;
                 }
             }
         }
@@ -471,8 +484,8 @@ class Prefs {
      */
     function isDirty($pref)
     {
-        if (isset($this->prefs[$pref]['acl'])) {
-            return ($this->prefs[$pref]['acl'] & _PREF_DIRTY);
+        if (isset($this->prefs[$pref]['mask'])) {
+            return ($this->prefs[$pref]['mask'] & _PREF_DIRTY);
         }
         return false;
     }
@@ -489,6 +502,41 @@ class Prefs {
         return empty($this->prefs[$pref]['val']);
     }
 
+    /**
+     * Modifies the "default" bit for the given preference.
+     *
+     * @param string $pref      The name of the preference to modify.
+     * @param boolean $bool     The new boolean value for the "default" bit.
+     */
+    function setDefault($pref, $bool)
+    {
+        if (isset($this->prefs[$pref])) {
+            if ($bool != $this->isDefault($pref)) {
+                if ($bool) {
+                    $this->prefs[$pref]['mask'] |=  _PREF_DEFAULT;
+                } else {
+                    $this->prefs[$pref]['mask'] &= ~_PREF_DEFAULT;
+                }
+            }
+        }
+    }
+
+    /**
+     * Determines if the current preference value is the default
+     * value from prefs.php or a user defined value
+     *
+     * @param string $pref      The name of the preference to check.
+     *
+     * @return boolean          True if the preference is the application default value.
+     */
+    function isDefault($pref)
+    {
+        if (isset($this->prefs[$pref]['mask'])) {
+            return ($this->prefs[$pref]['mask'] & _PREF_DEFAULT);
+        }
+        return false;
+    }
+
     /**
      * This is basically an abstract method that should be overridden by a
      * subclass implementation. It's here to retain code integrity in the
