@@ -1,5 +1,5 @@
 <?php
-// $Horde: horde/lib/Prefs/ldap.php,v 1.14.2.3 2001/12/19 12:41:42 jan Exp $
+// $Horde: horde/lib/Prefs/ldap.php,v 1.14.2.10 2002/05/31 15:39:35 jan Exp $
 
 require_once 'PEAR.php';
 
@@ -11,14 +11,18 @@ Horde::functionCheck('ldap_connect', true,
  *
  * Required values for $params:
  *      'hostspec'      The hostname of the LDAP server.
+ *      'port'          The port of the LDAP server.
  *      'basedn'        The base DN for the LDAP server.
  *      'uid'           The username search key.
+ *
+ * Optional values for $varams:
+ *      'version'       The version of the LDAP protocol to use.
+ *      'rootdn'        The DN of the root (administrative) account.
  *      'username'      The user as which to bind for write operations.
  *      'password'      'username's password for bind authentication.
- *      'always_bind'   Always bind to the LDAP server (store and retrieve).
  *
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.14.2.3 $
+ * @version $Revision: 1.14.2.10 $
  * @since   Horde 1.3
  * @package horde.prefs
  */
@@ -40,12 +44,7 @@ class Prefs_ldap extends Prefs {
         @var string $dn */
     var $dn = '';
 
-    /** Boolean indicating whether $connection has bound to the LDAP
-        server as an authenticated user (non-anonymous).
-        @var boolean $anonymous */
-    var $anonymous = true;
-    
-    
+
     /**
      * Constructs a new LDAP preferences object.
      *
@@ -63,34 +62,33 @@ class Prefs_ldap extends Prefs {
         $this->params = $params;
         $this->caching = $caching;
 
+        /* If a valid server port has not been specified, set the default. */
+        if (!isset($this->params['port']) || !is_int($this->params['port'])) {
+            $this->params['port'] = 389;
+        }
+
         /*
          * If $params['username'] is empty, set it to the name of the
-         * current user.  Also, the $params['password'] to the current
+         * current user.  Also, set $params['password'] to the current
          * user's password.
          *
          * Note: This assumes the user is allowed to modify their own LDAP
          *       entry.
          */
-        if (empty($this->params['username'])) {
+        if (empty($this->params['username']) &&
+            empty($this->params['rootdn'])) {
+            /* then */
             $this->params['username'] = $user;
             $this->params['password'] = $password;
         }
-
-        /* If the 'always_bind' parameter isn't specified, default to false. */
-        if (empty($this->params['always_bind'])) {
-            $this->params['always_bind'] = false;
-        }
     }
 
     /**
      * Opens a connection to the LDAP server.
      *
-     * @param boolean $bind  Boolean indicating whether or not to bind to the
-     *                       LDAP server using an authenticated connected.  
-     *
      * @return mixed         True on success or a PEAR_Error object on failure.
      */
-    function _connect($bind = false)
+    function _connect()
     {
         if (!is_array($this->params)) {
             Horde::fatal(new PEAR_Error(_("No configuration information specified for LDAP Preferences.")), __FILE__, __LINE__);
@@ -98,87 +96,97 @@ class Prefs_ldap extends Prefs {
         if (!isset($this->params['hostspec'])) {
             Horde::fatal(new PEAR_Error(_("Required 'hostspec' not specified in preferences configuration.")), __FILE__, __LINE__);
         }
-
-        /* Connect to the LDAP server anonymously. */
-        $conn = ldap_connect($this->params['hostspec']);
-        if (!$conn) {
-            Horde::fatal(new PEAR_Error(sprintf(_("Failed to open an LDAP connection to %s."), $this->params['hostspec'])), __FILE__, __LINE__);
-        }
-
-        /* Search for the user's full DN. */
-        $search = ldap_search($conn, $this->params['basedn'],
-                              $this->params['uid'] . '=' . $this->user,
-                              array($this->params['uid']));
-        $result = ldap_get_entries($conn, $search);
-        if (is_array($result)) {
-            $this->dn = $result[0]['dn'];
-        } else {
-            Horde::fatal(new PEAR_Error(sprintf(_("No entry found for %s."), $this->params['uid'])), __FILE__, __LINE__);
-        }
-
-        /* Store the connection handle at the instance level. */
-        $this->connection = $conn;
-        $this->_connected = true;
-        $this->anonymous = true;
-
-        /* Bind to the LDAP server, if requested. */
-        if ($bind) {
-            $this->_bind();
-        }
-
-        return true;
-    }
-
-    /**
-     * Bind to the LDAP server using authentication.
-     *
-     * @return mixed       True on success or a PEAR_Error object on failure.
-     */
-    function _bind()
-    {
-        /*
-         * If we're not already connected, return an error.  Invoking
-         * connect() again could lead to circular function calls.
-         */
-        if (!$this->_connected) {
-            Horde::fatal(new PEAR_Error(_("Attempt to bind without a valid connection.")), __FILE__, __LINE__);
-        }
-
-        /* Make sure the connection values for ldap_bind() were provided. */
         if (!isset($this->params['basedn'])) {
             Horde::fatal(new PEAR_Error(_("Required 'basedn' not specified in preferences configuration.")), __FILE__, __LINE__);
         }
         if (!isset($this->params['uid'])) {
             Horde::fatal(new PEAR_Error(_("Required 'uid' not specified in preferences configuration.")), __FILE__, __LINE__);
         }
-        if (!isset($this->params['username'])) {
+        if (!isset($this->params['username']) && !isset($this->params['rootdn'])) {
             Horde::fatal(new PEAR_Error(_("Required 'username' not specified in preferences configuration.")), __FILE__, __LINE__);
         }
         if (!isset($this->params['password'])) {
             Horde::fatal(new PEAR_Error(_("Required 'password' not specified in preferences configuration.")), __FILE__, __LINE__);
         }
 
-        /* Search for the full DN and bind to the LDAP server as that user. */
-        $search = ldap_search($this->connection, $this->params['basedn'],
-            $this->params['uid'] . '=' . $this->params['username'],
-            array($this->params['uid']));
-        $result = ldap_get_entries($this->connection, $search);
-        if (is_array($result)) {
-            $this->dn = $result[0]['dn'];
-            $bind = @ldap_bind($this->connection, $this->dn, $this->params['password']);
-            if (!$bind) {
-                Horde::fatal(new PEAR_Error(sprintf(_("Bind to server %s, dn %s as %s failed: [%d] %s"),
-                                                    $this->params['hostspec'],
-                                                    $this->dn,
-                                                    $this->params['uid'],
-                                                    ldap_errno($this->connection),
-                                                    ldap_error($this->connection))), __FILE__, __LINE__);
-            }
-        } else {
-            Horde::fatal(new PEAR_Error(sprintf(_("Attempt to bind failed: no entry found for %s."), $this->params['uid'])), __FILE__, __LINE__);
+        /* Connect to the LDAP server anonymously. */
+        $conn = ldap_connect($this->params['hostspec'], $this->params['port']);
+        if (!$conn) {
+            Horde::logMessage(
+                sprintf('Failed to open an LDAP connection to %s.',
+                        $this->params['hostspec']),
+                __FILE__, __LINE__);
+            return false;
         }
 
-        $this->anonymous = false;
+        /* Register our callback function to handle referrals. */
+        if (function_exists('ldap_set_rebind_proc') &&
+            !ldap_set_rebind_proc($conn, array($this, '_rebind_proc'))) {
+            /* then */
+            Horde::logMessage(
+                sprintf('Set rebind proc failed: [%d] %s',
+                        ldap_errno($this->connection),
+                        ldap_error($this->connection)),
+                __FILE__, __LINE__);
+            return false;
+        }
+
+        /* Set the LDAP protocol version */
+        if (isset($this->params['version'])) {
+            @ldap_set_option($this->conn, LDAP_OPT_PROTOCOL_VERSION,
+                             $params['version']);
+        }
+
+        /* Define the DN of the current user */
+        $this->dn = sprintf('%s=%s,%s', $this->params['uid'],
+                            $this->user,
+                            $this->params['basedn']);
+
+        /* And the DN of the authenticating user (may be the same as above) */
+        if (!empty($this->params['rootdn'])) {
+            $bind_dn = $this->params['rootdn'];
+        } else {
+            $bind_dn = sprintf('%s=%s,%s', $this->params['uid'],
+                               $this->params['username'],
+                               $this->params['basedn']);
+        }
+
+        /* Store the connection handle at the instance level. */
+        $this->connection = $conn;
+        $this->_connected = true;
+
+        /* Bind to the LDAP server as the authenticating user. */
+        $bind = @ldap_bind($this->connection, $bind_dn,
+                           $this->params['password']);
+        if (!$bind) {
+            Horde::logMessage(
+                sprintf('Bind to server %s:%d with DN %s failed: [%d] %s',
+                        $this->params['hostspec'],
+                        $this->params['port'],
+                        $bind_dn,
+                        ldap_errno($this->connection),
+                        ldap_error($this->connection)),
+                __FILE__, __LINE__);
+            return false;
+        }
+
+        /* Search for the user's full DN. */
+        $search = ldap_search($this->connection, $this->params['basedn'],
+                              $this->params['uid'] . '=' . $this->user,
+                              array('dn'));
+        if ($search) {
+            $result = ldap_get_entries($this->connection, $search);
+            if ($result && !empty($result[0]['dn'])) {
+                $this->dn = $result[0]['dn'];
+            }
+        } else {
+            Horde::logMessage(
+                sprintf('Failed to retrieve user\'s DN: [%d] %s',
+                        ldap_errno($this->connection),
+                        ldap_error($this->connection)),
+                __FILE__, __LINE__);
+            return false;
+        }
 
         return true;
     }
@@ -196,6 +204,52 @@ class Prefs_ldap extends Prefs {
         return ldap_close($this->connection);
     }
 
+    /**
+     * Callback function for LDAP referrals.  This function is called when an
+     * LDAP operation returns a referral to an alternate server.
+     */
+    function _rebind_proc($conn, $who)
+    {
+        /* Strip out the hostname we're being redirected to. */
+        $who = preg_replace(array('|^.*://|', '|:\d*$|'), '', $who);
+
+        /* Figure out the DN of the authenticating user. */
+        if (!empty($this->params['rootdn'])) {
+            $bind_dn = $this->params['rootdn'];
+        } else {
+            $bind_dn = sprintf('%s=%s,%s', $this->params['uid'],
+                               $this->params['username'],
+                               $this->params['basedn']);
+        }
+
+        /*
+         * Make sure the server we're being redirected to is in our list of
+         * valid servers.
+         */
+        if (!strstr($this->params['hostspec'], $who)) {
+            Horde::logMessage(
+                sprintf('Referral target %s for DN %s is not in the authorized server list!', $who, $bind_dn),
+                __FILE__, __LINE__);
+            return 1;
+        }
+
+        /* Bind to the new server. */
+        $bind = @ldap_bind($conn, $bind_dn, $this->params['password']);
+        if (!$bind) {
+            Horde::logMessage(
+                sprintf('Rebind to server %s:%d with DN %s failed: [%d] %s',
+                        $this->params['hostspec'],
+                        $this->params['port'],
+                        $bind_dn,
+                        ldap_errno($this->connection),
+                        ldap_error($this->connection)),
+                __FILE__, __LINE__);
+        }
+
+        return 0;
+    }
+
+
     /**
      * Retrieves the requested set of preferences from the user's LDAP
      * entry.
@@ -226,34 +280,70 @@ class Prefs_ldap extends Prefs {
 
         /* If we're not already connected, invoke the connect() method. */
         if (!$this->_connected) {
-            $this->_connect($this->params['always_bind']);
+            $this->_connect();
         }
 
+        /*
+         * Search for the multi-valued field containing the array of
+         * preferences.
+         */
         $search = ldap_search($this->connection, $this->params['basedn'],
-                              $this->params['uid'] . '=' . $this->user, $prefs);
+                              $this->params['uid'] . '=' . $this->user,
+                              array($this->scope . 'Prefs', 'hordePrefs'));
         if ($search) {
             $result = ldap_get_entries($this->connection, $search);
         } else {
-            Horde::fatal(new PEAR_Error(_("Failed to connect to LDAP preferences server.")), __FILE__, __LINE__);
+            Horde::logMessage('Failed to connect to LDAP preferences server.', __FILE__, __LINE__);
         }
 
-        if (isset($result) && is_array($result)) {
+        /* ldap_get_entries() converts attribute indexes to lowercase. */
+        $field = strtolower($this->scope . 'prefs');
+
+        if (isset($result)) {
             /*
              * Set the requested values in the $this->prefs hash based on
              * the contents of the LDAP result.
              *
+             * Preferences are stored as colon-separated name:value pairs.
+             * Each pair is stored as its own attribute off of the multi-
+             * value attribute named in: $this->scope . 'Prefs'
+             *
              * Note that Prefs::setValue() can't be used here because of the
              * check for the "changeable" bit.  We want to override that
              * check when populating the $this->prefs hash from the LDAP
              * server.
              */
-            foreach ($prefs as $pref) {
-                if (isset($result[0][$pref][0])) {
-                    $this->prefs[$pref]['val'] = $result[0][$pref][0];
+
+            /* Merge $this->scope prefs with shared prefs, if necessary. */
+            if (strcmp($this->scope, 'horde') != 0) {
+                if (isset($result[0][$field])) {
+                    $prefs = array_merge($result[0][$field],
+                                         $result[0]['hordeprefs']);
+                } else {
+                    $prefs = $result[0]['hordeprefs'];
+                }
+            } else {
+                $prefs = $result[0][$field];
+            }
+
+            foreach ($prefs as $prefstr) {
+
+                /* If the string doesn't contain a colon delimeter, skip it. */
+                if (substr_count($prefstr, ':') == 0) {
+                    continue;
+                }
+
+                /* Split the string into its name:value components. */
+                list($pref, $val) = split(':', $prefstr, 2);
+
+                /* Retrieve this preference. */
+                if (isset($this->prefs[$pref])) {
+                    $this->prefs[$pref]['val'] = base64_decode($val);
+                    $this->prefs[$pref]['default'] = false;
                 }
             }
         } else {
-            Horde::logMessage(_("No preferences were retrieved."), __FILE__, __LINE__);
+            Horde::logMessage('No preferences were retrieved.', __FILE__, __LINE__);
             return;
         }
 
@@ -264,7 +354,7 @@ class Prefs_ldap extends Prefs {
     }
 
     /**
-     * Stores preferences to LDAP server.
+     * Stores preferences to the LDAP server.
      *
      * @param array $prefs (optional) An array listing the preferences to be
      *                     stored.  If not specified, store all of the
@@ -303,35 +393,44 @@ class Prefs_ldap extends Prefs {
 
         /* If we're not already connected, invoke the connect(). */
         if (!$this->_connected) {
-            $this->_connect(true);
-        } else {
-            /* Bind if the LDAP server if we haven't already. */
-            if ($this->anonymous) {
-                $this->_bind();
-            }
+            $this->_connect();
         }
 
         /*
          * Build a hash of the preferences and their values that need to be
-         * stored in the LDAP server.
+         * stored in the LDAP server.  Because we have to update all of the
+         * values of a multi-value entry wholesale, we can't just pick out
+         * the dirty preferences; we must update everything.
          */
         $new_values = array();
-        foreach($dirty_prefs as $pref) {
-            $new_values[$pref] = Prefs::getValue($pref);
+        foreach($prefs as $pref) {
+            $entry = $pref . ':' . base64_encode(Prefs::getValue($pref));
+            $field = $this->getScope($pref) . 'Prefs';
+
+            $new_values[$field][] = $entry;
         }
 
-        /* Sent the hash of new values off to the LDAP server. */
-        if (!ldap_modify($this->connection, $this->dn, $new_values)) {
-            Horde::fatal(_("Unable to modified preferences."), __FILE__, __LINE__);
+        /* Send the hash to the LDAP server. */
+        $updated = true;
+        if (ldap_mod_replace($this->connection, $this->dn, $new_values)) {
+            foreach($dirty_prefs as $pref) {
+                $this->setDirty($pref, false);
+            }
+        } else {
+            Horde::logMessage(
+                sprintf('Unable to modify preferences: [%d] %s',
+                        ldap_errno($this->connection),
+                        ldap_error($this->connection)),
+                __FILE__, __LINE__);
+            $updated = false;
         }
 
-        /* Attemp to cache the preferences in the session. */
+        /* Attempt to cache the preferences in the session. */
         $this->cacheUpdate();
 
-        return true;
+        return $updated;
     }
 
-
     /**
      * Perform cleanup operations.
      *
@@ -346,6 +445,5 @@ class Prefs_ldap extends Prefs {
 
         parent::cleanup($all);
     }
-
 }
 ?>
