@@ -1,5 +1,5 @@
 <?php
-// $Horde: horde/lib/Prefs/sql.php,v 1.27.2.3 2001/12/10 19:14:40 chuck Exp $
+// $Horde: horde/lib/Prefs/sql.php,v 1.27.2.9 2002/05/31 15:39:35 jan Exp $
 
 /**
  * Preferences storage implementation for PHP's PEAR database abstraction
@@ -13,7 +13,7 @@
  *      'password'      The password associated with 'username'.
  *      'database'      The name of the database.
  *      'table'         The name of the preferences table in 'database'.
- * 
+ *
  * Required by some database implementations:
  *      'options'       Additional options to pass to the database.
  *      'tty'           The TTY on which to connect to the database.
@@ -30,7 +30,7 @@
  *  );
  *
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.27.2.3 $
+ * @version $Revision: 1.27.2.9 $
  * @since   Horde 1.3
  * @package horde.prefs
  */
@@ -101,10 +101,13 @@ class Prefs_sql extends Prefs {
             if (DB::isError($this->db) || DB::isWarning($this->db)) {
                 Horde::fatal($this->db, __FILE__, __LINE__);
             }
-            
+
+            /* Enable the "portability" option. */
+            $this->db->setOption('optimize', 'portability');
+
             $this->_connected = true;
         }
-        
+
         return true;
     }
 
@@ -131,7 +134,7 @@ class Prefs_sql extends Prefs {
      *                     retrieve. If not specified, retrieve all of the
      *                     preferences listed in the $prefs hash.
      *
-     * @return mixed       True on success or a PEAR_Error object on failure. 
+     * @return mixed       True on success or a PEAR_Error object on failure.
      */
     function retrieve($prefs = array())
     {
@@ -151,14 +154,12 @@ class Prefs_sql extends Prefs {
             return true;
         }
 
-        /* If we're not already connected, invoke the _connect() method. */
-        if (!$this->_connected) {
-            $this->_connect();
-        }
+        /* Make sure we're connected. */
+        $this->_connect();
 
         /* Build the SQL query. */
         $query = 'select pref_scope, pref_name, pref_value from ';
-        $query .= $this->params['table'] . ' '; 
+        $query .= $this->params['table'] . ' ';
         $query .= 'where pref_uid = ' . $this->db->quote($this->user);
         $query .= ' and (pref_scope = ' . $this->db->quote($this->scope);
         $query .= " or pref_scope = 'horde') order by pref_scope";
@@ -169,7 +170,7 @@ class Prefs_sql extends Prefs {
         if (isset($result) && !DB::isError($result)) {
             $row = $result->fetchRow(DB_FETCHMODE_ASSOC);
             if (DB::isError($row)) {
-                Horde::logMessage(_("No preferences were retrieved."), __FILE__, __LINE__);
+                Horde::logMessage('No preferences were retrieved.', __FILE__, __LINE__);
                 return;
             }
 
@@ -184,6 +185,7 @@ class Prefs_sql extends Prefs {
                 $name = trim($row['pref_name']);
                 if (in_array($name, $prefs)) {
                     $this->prefs[$name]['val'] = $row['pref_value'];
+                    $this->prefs[$name]['default'] = false;
                     $this->setDirty($name, false);
                 }
                 $row = $result->fetchRow(DB_FETCHMODE_ASSOC);
@@ -191,13 +193,13 @@ class Prefs_sql extends Prefs {
             $result->free();
 
         } else {
-            Horde::logMessage(_("No preferences were retrieved."), __FILE__, __LINE__);
+            Horde::logMessage('No preferences were retrieved.', __FILE__, __LINE__);
             return;
         }
 
         /* Update the session cache. */
         $this->cacheUpdate();
-        
+
         return true;
     }
 
@@ -239,36 +241,58 @@ class Prefs_sql extends Prefs {
             return true;
         }
 
-        /* If we're not already connected, invoke the connect() method. */
-        if (!$this->_connected) {
-            $this->_connect();
-        }
+        /* Make sure we're connected. */
+        $this->_connect();
 
         /*
-         * Loop through the "dirty" preferences.  If our attempt to insert
-         * a new row fails, try to update an existing one.
+         * Loop through the "dirty" preferences.  If a row already exists for
+         * this preference, attempt to update it.  Otherwise, insert a new row.
          */
         foreach ($dirty_prefs as $name) {
             $scope = $this->getScope($name);
 
-            /* Attempt an insert. */
-            $query  = 'insert into ' . $this->params['table'] . ' ';
-            $query .= '(pref_uid, pref_scope, pref_name, pref_value) values';
-            $query .= '(' . $this->db->quote($this->user) . ', ';
-            $query .= $this->db->quote($scope) . ', ' . $this->db->quote($name) . ', ';
-            $query .= $this->db->quote($this->getValue($name)) . ')';
+            /* Does an entry already exist for this preference? */
+            $query = 'select pref_value from ';
+            $query .= $this->params['table'] . ' ';
+            $query .= 'where pref_uid = ' . $this->db->quote($this->user);
+            $query .= ' and pref_name = ' . $this->db->quote($name);
+            $query .= ' and (pref_scope = ' . $this->db->quote($scope);
+            $query .= " or pref_scope = 'horde')";
+
+            /* Execute the query. */
             $result = $this->db->query($query);
-            
-            /* If the insert failed, attempt an update. */
-            if ($result !== DB_OK) {
+
+            /* Return an error if the query fails. */
+            if (!isset($result) || DB::isError($result)) {
+                Horde::logMessage('Failed retrieving prefs for ' . $this->user, __FILE__, __LINE__, LOG_NOTICE);
+                return (new PEAR_Error(_("Failed retrieving preferences.")));
+            }
+
+            /* Is there an existing row for this preference? */
+            $row = $result->fetchRow();
+            if ($row && !DB::isError($row)) {
+                /* Update the existing row. */
                 $query = 'update ' . $this->params['table'] . ' ';
                 $query .= 'set pref_value = ' . $this->db->quote($this->getValue($name));
                 $query .= ' where pref_uid = ' . $this->db->quote($this->user);
                 $query .= ' and pref_name = ' . $this->db->quote($name);
                 $query .= ' and pref_scope = ' . $this->db->quote($scope);
                 $result = $this->db->query($query);
-                
-                /* Return an error if the update fails, too. */
+
+                /* Return an error if the update fails. */
+                if (PEAR::isError($result)) {
+                    Horde::fatal($result, __FILE__, __LINE__);
+                }
+            } else {
+                /* Insert a new row. */
+                $query  = 'insert into ' . $this->params['table'] . ' ';
+                $query .= '(pref_uid, pref_scope, pref_name, pref_value) values';
+                $query .= '(' . $this->db->quote($this->user) . ', ';
+                $query .= $this->db->quote($scope) . ', ' . $this->db->quote($name) . ', ';
+                $query .= $this->db->quote($this->getValue($name)) . ')';
+                $result = $this->db->query($query);
+
+                /* Return an error if the insert fails. */
                 if (PEAR::isError($result)) {
                     Horde::fatal($result, __FILE__, __LINE__);
                 }
