@@ -1,5 +1,5 @@
 <?php
-// $Horde: horde/lib/Registry.php,v 1.59.2.5 2001/12/23 13:46:17 jan Exp $
+// $Horde: horde/lib/Registry.php,v 1.59.2.12 2002/04/14 16:38:40 jan Exp $
 
 require_once 'PEAR.php';
 require_once dirname(__FILE__) . '/Horde.php';
@@ -12,12 +12,12 @@ require_once dirname(__FILE__) . '/Horde.php';
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.59.2.5 $
+ * @version $Revision: 1.59.2.12 $
  * @since   Horde 1.3
- * @package horde.registry
+ * @package horde
  */
 class Registry {
-    
+
     /**
      * Hash representing the actual registry structure.
      * @var array $registry
@@ -47,7 +47,7 @@ class Registry {
      * @var array $prefsCache
      */
     var $prefsCache = array();
-    
+
     /**
      * Cache of application configurations.
      * @var array $confCache
@@ -59,7 +59,7 @@ class Registry {
      * @var array $used
      */
     var $used;
-    
+
     /**
      * Returns a reference to the global Registry object, only
      * creating it if it doesn't already exist.
@@ -80,25 +80,33 @@ class Registry {
     }
 
     /**
-     * Create a new registry instance.
+     * Create a new registry instance. Should never be called except
+     * by &Registry::singleton().
+     *
+     * @access private
      */
     function Registry()
     {
         $base = dirname(__FILE__) . '/..';
 
+        // read in and evaluate the registry file
+        include_once $base . '/config/registry.php';
+
         /* Initialize the localization routines and variables  */
         include_once $base . '/lib/Lang.php';
         Lang::setLang();
-        Lang::setDomain('horde', $base . '/locale', $this->getCharset());
-        
-        // read in and evaluate the registry file
-        include_once $base . '/config/registry.php';
+        Lang::setTextdomain('horde', $base . '/locale', Lang::getCharset());
 
         /* Set the default cookie_path to the Horde webroot */
         if (!isset($this->applications['horde']['cookie_path'])) {
             $this->applications['horde']['cookie_path'] = $this->applications['horde']['webroot'];
         }
 
+        /* Make sure the cookie path isn't empty - use '/' instead. */
+        if (empty($this->applications['horde']['cookie_path'])) {
+            $this->applications['horde']['cookie_path'] = '/';
+        }
+
         /* Set other common defaults like templates and graphics */
         foreach (array_keys($this->applications) as $appName) {
             $app = &$this->applications[$appName];
@@ -124,28 +132,32 @@ class Registry {
     function allowGuests($app = null)
     {
         if (!isset($app)) $app = $this->getApp();
-        
+
         return (!empty($this->applications[$app]['allow_guests']));
     }
 
     /**
      * Determine if a method has been registered with the registry.
-     * 
+     *
      * @param string $method The full name of the method to check for.
-     * 
+     *
      * @return boolean Whether or not the method is registered.
      */
-    function hasMethod($method)
+    function hasMethod($method, $app = null)
     {
         list($type, $subtype) = explode('/', $method);
-        return !empty($this->registry[$type][$subtype]);
+        if (is_null($app)) {
+            return !empty($this->registry[$type][$subtype]);
+        } else {
+            return isset($this->services[$app][$type][$subtype]);
+        }
     }
 
     /**
      * Returns the handler for the given method.
-     * 
+     *
      * @param string $method The full name of the method to check for.
-     * 
+     *
      * @return string The handler for the method.
      */
     function getMethod($method)
@@ -169,7 +181,7 @@ class Registry {
             // no callback defined
             return PEAR::raiseError('The method "' . $method . '" is not defined in the Horde registry,');
         }
-        
+
         list($type, $subtype) = explode('/', $method);
         return $this->callByPackage($this->registry[$type][$subtype], $method, $args);
     }
@@ -212,7 +224,7 @@ class Registry {
         if (!@is_readable($file)) {
             return PEAR::raiseError('The file defining the ' . $method . ' call (' . $file . ') is not readable.');
         }
-        
+
         // Switch application contexts, if necessary, now, before
         // including any files which might do it for us.
         $pushed = $this->pushApp($package);
@@ -222,8 +234,8 @@ class Registry {
             return PEAR::raiseError('The function implementing ' . $method . ' (' . $function . ') is not defined in ' . $file . '.');
         }
 
-        $res = call_user_func_array($function, $args); 
-        
+        $res = call_user_func_array($function, $args);
+
         // If we changed application context in the course of this
         // call, undo that change now.
         if ($pushed) {
@@ -261,7 +273,7 @@ class Registry {
             // no link defined
             return null;
         }
-        
+
         list($type, $subtype) = explode('/', $method);
         return $this->linkByPackage($this->registry[$type][$subtype], $method, $args, $extra);
     }
@@ -354,11 +366,9 @@ class Registry {
      */
     function shutdown()
     {
-        /* Having $registry as a global here is slightly twisted, but
-         * it already exists by this point, and allows config files to
-         * invoke $registry->() functions for path querying. */
+        /* Don't make config files global $registry themselves. */
         global $registry;
-        
+
         if (!empty($this->used) && is_array($this->used)) {
             foreach ($this->used as $key => $val) {
                 list($type, $subtype) = explode('/', $key);
@@ -369,7 +379,7 @@ class Registry {
             }
         }
     }
-    
+
     /**
      * Include dependency files for a method immediately, instead of
      * putting inclusion off until shutdown.
@@ -391,10 +401,12 @@ class Registry {
      */
     function applicationFilePath($path, $app = null)
     {
-        if (!isset($app)) {
+        if (is_null($app)) {
             $app = $this->getApp();
         }
-        
+        if (!isset($this->applications[$app])) {
+            Horde::fatal(new PEAR_Error(sprintf(_("'%s' is not configured in the Horde Registry."), $app)), __FILE__, __LINE__);
+        }
         return str_replace('%application%', $this->applications[$app]['fileroot'], $path);
     }
 
@@ -407,7 +419,7 @@ class Registry {
         if (!isset($app)) {
             $app = $this->getApp();
         }
-        
+
         return str_replace('%application%', $this->applications[$app]['webroot'], $path);
     }
 
@@ -425,44 +437,43 @@ class Registry {
     function pushApp($app)
     {
         static $session_started;
-        
+
         if ($app != $this->getApp()) {
             array_push($this->appStack, $app);
-            
+
             /* Import Horde's configuration values. */
             $this->importConfig('horde');
-            
+
             /* Start the session if this is the first application to
                be loaded. */
             if (!isset($session_started)) {
                 $session_started = true;
                 session_set_cookie_params(0, $this->getParam('cookie_path'), $this->getParam('cookie_domain'));
-                session_name($GLOBALS['conf']['session_name']);
+                session_name(urlencode($GLOBALS['conf']['session_name']));
                 @session_start();
             }
-            
+
             /* Load preferences after the configuration has been
                loaded and the session started, to make sure we have
                all the information we need. */
             $this->loadPrefs($app);
-            
-            /* Reset the language in case that there is a different one 
+
+            /* Reset the language in case that there is a different one
                selected in the preferences. */
             include_once HORDE_BASE . '/lib/Lang.php';
+            $language = '';
             if (isset($this->prefsCache[$app]) && isset($this->prefsCache[$app]->prefs['language'])) {
-                $language = $this->prefsCache[$app]->prefs['language']['val'];
-                if (isset($language)) {
-                    Lang::setLang($language);
-                }
+                $language = $this->prefsCache[$app]->getValue('language');
             }
-            Lang::setDomain($app, $this->applications[$app]['fileroot'] . '/locale', $this->getCharset());
-            
+            Lang::setLang($language);
+            Lang::setTextdomain($app, $this->applications[$app]['fileroot'] . '/locale', Lang::getCharset());
+
             /* Import this application's configuration values. */
             $this->importConfig($app);
-            
+
             return true;
         }
-        
+
         return false;
     }
 
@@ -489,7 +500,7 @@ class Registry {
             if (isset($language)) {
                 Lang::setLang($language);
             }
-            Lang::setDomain($current, $this->applications[$current]['fileroot'] . '/locale', $this->getCharset());
+            Lang::setTextdomain($current, $this->applications[$current]['fileroot'] . '/locale', Lang::getCharset());
         }
 
         return $previous;
@@ -518,11 +529,9 @@ class Registry {
      */
     function importConfig($app)
     {
-        /* Having $registry as a global here is slightly twisted, but
-         * it already exists by this point, and allows config files to
-         * invoke $registry->() functions for path querying. */
+        /* Don't make config files global $registry themselves. */
         global $registry;
-        
+
         /* Cache config values so that we don't re-read files on every
            popApp() call. */
         if (!isset($this->confCache[$app])) {
@@ -532,14 +541,14 @@ class Registry {
             } else {
                 $conf = $this->confCache['horde'];
             }
-            
+
             if ($app !== 'horde') {
                 @include $this->applications[$app]['fileroot'] . '/config/conf.php';
             }
-            
+
             $this->confCache[$app] = &$conf;
         }
-        
+
         $GLOBALS['conf'] = &$this->confCache[$app];
     }
 
@@ -551,31 +560,40 @@ class Registry {
      */
     function loadPrefs($app = null)
     {
-        /* If there is no logged in user, don't do anything -
-           preferences are unavailable in those situations. */
+        /* If there is no logged in user, return an empty Prefs::
+         * object with just default preferences. */
         @include_once HORDE_BASE . '/lib/Auth.php';
-        if (!Auth::getAuth()) {
-            return;
-        }
-        
+        @include_once HORDE_BASE . '/lib/Prefs.php';
+
         if (!isset($app)) {
             $app = $this->getApp();
         }
 
+        /* Don't load an actual prefs driver or cache guest
+         * preferences. */
+        if (!Auth::getAuth()) {
+            $prefs = &Prefs::factory('none', $app, '', '', array());
+            $prefs->setDefaults($this->getParam('fileroot', 'horde') . '/config/prefs.php');
+            $prefs->setDefaults($this->getParam('fileroot') . '/config/prefs.php');
+
+            $GLOBALS['prefs'] = &$prefs;
+            return;
+        }
+
         /* Cache prefs objects so that we don't re-load them on every
            popApp() call. */
         if (!isset($this->prefsCache[$app])) {
-            @include_once HORDE_BASE . '/lib/Prefs.php';
-            
             global $conf;
             $prefs = &Prefs::factory($conf['prefs']['driver'], $app,
                                      Auth::getAuth(), Auth::getCredential('password'),
                                      $conf['prefs']['params']);
-            $prefs->setDefaults($this->getFileRoot() . '/config/prefs.php');
+            $prefs->setDefaults($this->getParam('fileroot', 'horde') . '/config/prefs.php');
+            $prefs->setDefaults($this->getParam('fileroot') . '/config/prefs.php');
             $prefs->retrieve();
+
             $this->prefsCache[$app] = &$prefs;
         }
-        
+
         $GLOBALS['prefs'] = &$this->prefsCache[$app];
     }
 
@@ -644,13 +662,18 @@ class Registry {
         if (is_null($app)) {
             $app = $this->getApp();
         }
-        
+
         if (isset($this->applications[$app][$parameter])) {
-            return $this->applications[$app][$parameter];
+            $ret = $this->applications[$app][$parameter];
         } else {
-            return isset($this->applications['horde'][$parameter]) ?
+            $ret = isset($this->applications['horde'][$parameter]) ?
                 $this->applications['horde'][$parameter] : null;
         }
+        if ($parameter == 'name') {
+            return gettext($ret);
+        } else {
+            return $ret;
+        }
     }
 
     /**
@@ -661,11 +684,14 @@ class Registry {
      * @param optional string $app The name of the application.
      * @return string URL pointing to the inital page of the application.
      */
-    function getInitialPage($app = '')
+    function getInitialPage($app = null)
     {
-        if (empty($app)) {
+        if (is_null($app)) {
             $app = $this->getApp();
         }
+        if (!isset($this->applications[$app])) {
+            Horde::fatal(new PEAR_Error(sprintf(_("'%s' is not configured in the Horde Registry."), $app)), __FILE__, __LINE__);
+        }
         return $this->applications[$app]['webroot'] . '/' . (isset($this->applications[$app]['initial_page']) ? $this->applications[$app]['initial_page'] : '');
     }
 
@@ -679,7 +705,7 @@ class Registry {
     {
         return $this->applications[(empty($app) ? $this->getApp() : $app)]['fileroot'];
     }
-    
+
     /**
      * Return the charset for the current language.
      *
