@@ -1,5 +1,5 @@
 <?php
-// $Horde: horde/lib/base.php,v 1.3.2.1 2001/11/10 00:02:53 chuck Exp $
+// $Horde: horde/lib/base.php,v 1.3.2.3 2002/04/17 22:58:27 jan Exp $
 
 /*
  * Horde base inclusion file.
@@ -20,6 +20,7 @@ require_once HORDE_BASE . '/lib/Registry.php';
 $registry = &Registry::singleton();
 $registry->pushApp('horde');
 $conf = &$GLOBALS['conf'];
+@define('HORDE_TEMPLATES', $registry->getParam('templates'));
 
 // set error reporting according to config settings
 error_reporting($conf['debug_level']);
@@ -30,9 +31,14 @@ set_time_limit($conf['max_exec_time']);
 // Horde base libraries
 require_once HORDE_BASE . '/lib/Horde.php';
 require_once HORDE_BASE . '/lib/Auth.php';
-require_once HORDE_BASE . '/lib/Browser.php';
 
 // Browser detection object
+require_once HORDE_BASE . '/lib/Browser.php';
 $browser = new Browser();
 
+// Notification System
+require_once HORDE_BASE . '/lib/Notification.php';
+$notification = &Notification::singleton();
+$notification->attach('status');
+
 ?>
