@@ -1,11 +1,11 @@
 <?php
 /*
- * $Horde: horde/login.php,v 2.55.2.6 2002/01/02 17:05:08 jan Exp $
+ * $Horde: horde/login.php,v 2.55.2.13 2002/06/08 04:15:55 chuck Exp $
  *
  * Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2002 Jon Parise <jon@horde.org>
  *
- * See the enclosed file COPYING for license information (LGPL).  If you
+ * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  */
 
@@ -54,14 +54,25 @@ if ($browser->hasFeature('wml')) {
     $registry->applications['horde']['templates'] .= '/wml';
 }
 
-$title = _("Horde Login");
+/* Map the various values for $reason to more descriptive status messages. */
+$reasons = array('login'   => '',
+                 'session' => sprintf(_("Your %s session has expired. Please login again."), $registry->getParam('name')),
+                 'logout'  => _("You have been logged out.<br />Thank you for using the system."),
+                 'failed'  => _("Login failed for some reason. Most likely your username or password was entered incorrectly."));
+
 if (Auth::getAuth()) {
+    $title = _("My Summary");
+    $js_onLoad = null;
+    if ($prefs->getValue('summary_refresh_time')) {
+        $refresh_time = $prefs->getValue('summary_refresh_time');
+        $refresh_url = Horde::applicationUrl('login.php');
+    }
     include_once HORDE_BASE . '/lib/Menu.php';
-    $fullname = ucfirst(Auth::getAuth());
+    $fullname = Auth::getAuth();
     $template = 'user.inc';
     $columns = array();
     foreach ($registry->applications as $app => $info) {
-        if (isset($registry->services[$app]['horde']['summary'])) {
+        if (isset($registry->services[$app]['horde']['summary']) && $registry->getParam('show', $app)) {
             $summary = $registry->callByPackage($app, 'horde/summary');
             if (!PEAR::isError($summary)) {
                 $columns[] = $summary;
@@ -76,11 +87,12 @@ if (Auth::getAuth()) {
     header('Location: ' . Horde::url($registry->link('auth/login', array('url' => Horde::url($url, true))), true));
     exit;
 } else {
+    $title = _("Horde Login");
     $js_onLoad = 'setFocus()';
     $template = 'login.inc';
 }
-require $registry->getTemplatePath("horde") . '/common-header.inc';
-require $registry->getTemplatePath("horde") . '/login/' . $template;
-require $registry->getTemplatePath("horde") . '/common-footer.inc';
+require HORDE_TEMPLATES . '/common-header.inc';
+require HORDE_TEMPLATES . '/login/' . $template;
+require HORDE_TEMPLATES . '/common-footer.inc';
 
 ?>
