@@ -1,11 +1,11 @@
 <?php
 /*
- * $Horde: horde/problem.php,v 2.62.2.3 2002/01/02 17:05:10 jan Exp $
+ * $Horde: horde/problem.php,v 2.62.2.8 2002/04/14 15:29:54 jan Exp $
  *
  * Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2002 Jon Parise <jon@horde.org>
  *
- * See the enclosed file COPYING for license information (LGPL).  If you
+ * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  */
 
@@ -15,24 +15,31 @@ function returnToPage() {
     header('Location: ' . $returnURL);
 }
 
-require_once './lib/base.php';
-require_once './lib/version.php';
+define('HORDE_BASE', dirname(__FILE__));
+require_once HORDE_BASE . '/lib/base.php';
+require_once HORDE_BASE . '/lib/Identity.php';
+require_once HORDE_BASE . '/lib/version.php';
 
-$name = Horde::getFormData('name', '');
-$email = Horde::getFormData('email', '');
+if (!Auth::getAuth()) {
+    returnToPage();
+}
+
+$identity = new Identity();
+$name = Horde::getFormData('name', $identity->getValue('fullname'));
+$email = Horde::getFormData('email', $identity->getValue('from_addr'));
 $subject = Horde::getFormData('subject', '');
 $message = Horde::getFormData('message', '');
 
 /* Run through action handlers */
-$actionID = Horde::getFormData('actionID', NO_ACTION);
+$actionID = Horde::getFormData('actionID');
 switch ($actionID) {
  case HORDE_SEND_PROBLEM_REPORT:
-     include_once './lib/Text.php';
-     
+     include_once HORDE_BASE . '/lib/Text.php';
+
      if (!empty($subject) && !empty($message)) {
-         include_once './lib/MIME.php';
-         include_once './lib/MIME/Message.php';
-         
+         include_once HORDE_BASE . '/lib/MIME.php';
+         include_once HORDE_BASE . '/lib/MIME/Message.php';
+
          // add a Received header for the hop from browser to server.
          $remote = (!empty($HTTP_SERVER_VARS['REMOTE_HOST'])) ? $HTTP_SERVER_VARS['REMOTE_HOST'] : $HTTP_SERVER_VARS['REMOTE_ADDR'];
          $headers['Received'] = 'from ' . $remote . ' (';
@@ -58,19 +65,19 @@ switch ($actionID) {
          $recipients = $conf['problems']['email'];
          $headers['Subject'] = _("[Problem Report]") . ' ' . $subject;
          $headers['User-Agent'] = 'Horde ' . HORDE_VERSION;
-         
+
          $message = str_replace("\r\n", "\n", $message);
          $message = "\nThis problem report was received from $remote. " .
-             'The user clicked the problem report link from the following location: ' . 
+             'The user clicked the problem report link from the following location: ' .
              Horde::getFormData('return_url', 'No requesting page') . "\n\n" . $message;
-         
+
          $mime = new MIME_Message();
          $body = new MIME_Part('text/plain', Text::wrap($message, 80, "\n"));
-         
+
          $mime->addPart($body);
          $headers = $mime->header($headers);
          $msg = $mime->toString();
-         
+
          include_once 'Mail.php';
          $mailer = &Mail::factory($conf['mailer']['type'], $conf['mailer']['params']);
          if (!PEAR::isError($mailer->send($recipients, $headers, $msg))) {
@@ -85,7 +92,7 @@ switch ($actionID) {
          $label = _("Describe the Problem");
      }
      break;
-     
+
  case HORDE_CANCEL_PROBLEM_REPORT:
      returnToPage();
      exit;
@@ -97,11 +104,12 @@ if (empty($label)) {
 }
 
 $title = _("Problem Description");
-require $registry->getTemplatePath('horde') . '/common-header.inc';
-require $registry->getTemplatePath('horde') . '/problem/problem.inc';
+$js_onLoad = null;
+require HORDE_TEMPLATES . '/common-header.inc';
+require HORDE_TEMPLATES . '/problem/problem.inc';
 if ($browser->hasFeature('javascript')) {
-    include $registry->getTemplatePath('horde') . '/problem/javascript.inc';
+    include HORDE_TEMPLATES . '/problem/javascript.inc';
 }
-require $registry->getTemplatePath('horde') . '/common-footer.inc';
+require HORDE_TEMPLATES . '/common-footer.inc';
 
 ?>
