@@ -1,15 +1,15 @@
--- $Horde: horde/scripts/db/category.sql,v 1.2.2.6 2001/12/31 03:16:40 jon Exp $
+-- $Horde: horde/scripts/db/category.sql,v 1.2.2.8 2002/03/11 19:31:35 chuck Exp $
 
 CREATE TABLE horde_categories (
        category_id INT not null,
        group_uid VARCHAR(255) not null,
-       user_uid VARCHAR(255),
+       user_uid VARCHAR(255) not null,
        category_name VARCHAR(255) not null,
 -- There is no portable way to do this apparently. If your db doesn't allow varchars
 -- greater than 255 characters, then maybe it allows TEXT columns, so try the second
 -- line.
-       category_data VARCHAR(2048) null,
---     category_data TEXT null,
+       category_data VARCHAR(2048),
+--     category_data TEXT,
        category_serialized SMALLINT DEFAULT 0 not null,
        category_updated TIMESTAMP,
        PRIMARY KEY (category_id)
