@@ -1,4 +1,3 @@
-<?php // $Horde: horde/templates/javascript/open_help_win.js,v 1.3 2001/07/17 10:13:19 avsm Exp $ ?>
 <script language="JavaScript" type="text/javascript">
 <!--
 function open_help_win(module, topic)
@@ -20,17 +19,17 @@ function open_help_win(module, topic)
     if (window.innerHeight) screen_height = window.innerHeight;
 
     if (topic == null) {
-        win_location = '/help.php?module=' + module; 
+        win_location = '/help.php?module=' + module;
     } else if (topic == "") {
         win_location = '/help.php?module=' + module + '&amp;show=topics';
     } else {
         win_location = '/help.php?module=' + module + '&amp;topic=' + topic;
     }
-    
+
     win_top  = screen_height - help_win_height - 20;
     win_left = screen_width  - help_win_width  - 20;
     HelpWin  = window.open(
-        '<?= $registry->getWebRoot('horde') ?>' + win_location,
+        '<?= $registry->getParam('webroot', 'horde') ?>' + win_location,
         'HelpWindow',
         'width='+help_win_width+',height='+help_win_height+',top='+win_top+',left='+win_left
     );
