@@ -1,7 +1,8 @@
 <?php
 /*
- * $Horde: horde/test.php,v 1.44.2.3 2002/01/02 17:05:12 jan Exp $
+ * $Horde: horde/test.php,v 1.44.2.8 2002/06/10 15:00:22 jan Exp $
  *
+ * Copyright 2002 Brent J. Nordquist <bjn@horde.org>
  * Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2002 Jon Parise <jon@horde.org>
  *
@@ -20,6 +21,11 @@ $horde_test_count = &$HTTP_SESSION_VARS['horde_test_count'];
 
 /* We want to be as verbose as possible here. */
 error_reporting(E_ALL);
+
+/* Set character encoding. */
+header('Content-type: text/html; charset=utf-8');
+header('Vary: Accept-Language');
+
 function testErrorHandler($errno, $errmsg, $filename, $linenum, $vars) {
     global $pear, $newpear, $pearmail, $pearlog, $peardb, $unkerr;
     if (preg_match("/PEAR\.php/", $errmsg)) {
@@ -47,6 +53,7 @@ function status($foo) {
 
 /* Horde versions */
 $versions = array();
+$testphp = array();
 require_once './lib/version.php';
 $versions['horde'] = HORDE_VERSION;
 
@@ -58,6 +65,9 @@ foreach ($this->applications as $module => $details) {
         include_once $details['fileroot'] . '/lib/version.php';
         eval('$ver = ' . strtoupper($module) . '_VERSION;');
         $versions[$module] = $ver;
+        if ($module != 'horde' && @is_readable($details['fileroot'] . '/test.php')) {
+            $testphp[$module] = $details['webroot'] . '/test.php';
+        }
     }
 }
 
@@ -146,6 +156,8 @@ $xml = extension_loaded('xml');
 
 /* PHP Settings */
 $magic_quotes_runtime = !get_magic_quotes_runtime();
+$file_uploads = ini_get('file_uploads');
+$short_open_tag = ini_get('short_open_tag');
 
 /* PEAR */
 $pear = true;
@@ -221,10 +233,19 @@ h1 { font-size: 12pt; color: black; font-family: Verdana,Geneva,Arial,Helvetica,
 <ul>
 <?php
 foreach ($versions as $module => $ver) {
+    if (!empty($testphp[$module])) {
+        $testpath = $testphp[$module];
+    } else {
+        $testpath = '';
+    }
     $module = ucfirst($module);
     if ($module == 'Imp')
         $module = 'IMP';
-    echo "<li>$module: $ver</li>\n";
+    if ($testpath) {
+        echo "<li>$module: $ver (<a href=\"$testpath\">run $module tests</a>)</li>\n";
+    } else {
+        echo "<li>$module: $ver</li>\n";
+    }
 }
 ?>
 </ul>
@@ -242,22 +263,21 @@ foreach ($versions as $module => $ver) {
         echo '        <li><font color="red">This is a beta/prerelease version of PHP4. You need to upgrade to a release version.</font></li>';
         $requires = 1;
     } elseif ($phpver['major'] == '4.0') {
-        if ($phpver['minor'] < '6') {
-            echo '        <li><font color="red">This version of PHP is not supported. You need to upgrade to a more recent version.</font></li>';
-            $requires = 1;
-        } elseif (!$newpear) {
-            echo '        <li><font color="orange">This version of PHP is supported, but you need a more recent version of PEAR.  <b>See below.</b></font></li>';
-            $requires = 1;
-        } else {
-            echo '        <li><font color="green">You are running a supported version of PHP.</font></li>';
+        echo '        <li><font color="red">This version of PHP is not supported. You need to upgrade to a more recent version.</font></li>';
+        $requires = 1;
+    } elseif ($phpver['major'] == '4.1' || $phpver['major'] == '4.2' || $phpver['major'] == '4.3') {
+        if ($phpver['major'] == '4.1' && $phpver['minor'] < '2') {
+            $insecure = 1;
         }
-    } elseif ($phpver['major'] == '4.1' || $phpver['major'] == '4.2') {
         echo '        <li><font color="green">You are running a supported version of PHP.</font></li>';
     } else {
         echo '        <li><font color="orange">Wow, a mystical version of PHP from the future. Let <a href="mailto:dev@lists.horde.org">dev@lists.horde.org</a> know what version you have so we can fix this script.</font></li>';
     }
     if (!empty($requires)) {
-        echo '        <li>Horde requires PHP 4.1.0 (or PHP 4.0.6 or greater <b>with</b> PEAR 4.1.0).</li>';
+        echo '        <li>Horde requires PHP 4.1.0.</li>';
+    }
+    if (!empty($insecure)) {
+        echo '        <li><font color="orange">This version of PHP contains a serious security vulnerability in its upload code.</font> You should apply the patch or upgrade to 4.1.2 or later as soon as possible.</li>';
     }
     echo '</ul>';
 ?>
@@ -280,10 +300,18 @@ foreach ($versions as $module => $ver) {
 
 <h1>Miscellaneous PHP Settings</h1>
 <ul>
+    <li>short_open_tag enabled: <?php echo status($short_open_tag) ?></li>
+    <?php if (!$short_open_tag) { ?>
+    <li><font color="red"><b>short_open_tags must be enabled to make Horde work.</b></font></li>
+    <?php } ?>
     <li>magic_quotes_runtime set to Off: <?php echo status($magic_quotes_runtime); ?></li>
     <?php if (!$magic_quotes_runtime) { ?>
     <li><font color="red"><b>magic_quotes_runtime may cause problems with database inserts, etc. Turn it off.</b></font></li>
     <?php } ?>
+    <li>file_uploads enabled: <?php echo status($file_uploads) ?></li>
+    <?php if (!$file_uploads) { ?>
+    <li><font color="orange"><b>file_uploads must be enabled for some features like sending emails with IMP.</b></font></li>
+    <?php } ?>
 </ul>
 
 <h1>PHP Sessions</h1>
